@@ -217,6 +217,7 @@ ContactParsingObject.prototype.parseDetailedFullNameInfo = function (data) {
  * Function will parse data and return an object with different fields
  * @param array data[element id] => value
  * @return object result[key] => value
+ * This function is not useful anymore as we are not using parser for address.
  */
 ContactParsingObject.prototype.parseDetailedAddressInfo = function (data) {
 	// reset variable
@@ -263,6 +264,11 @@ ContactParsingObject.prototype.parseDetailedAddressInfo = function (data) {
 			singleLine = addressParts.shift();
 			this.incompleteInfo = true; // information entered is incomplete or unclear
 			break;
+		default:
+			result["country"] = addressParts.pop();
+			singleLine = addressParts.pop();
+			result["street"] = addressParts.join(NBSP);
+			break;
 	}
 
 	if(typeof singleLine != "undefined" && singleLine.length >= 1) {
