@@ -638,7 +638,7 @@ function validateEmailAddress(fieldString, forceSingleAddress, suppressPopupMsg)
 		// check e-mail address
 		var email = data[i].trim();
 		// RFC 5322 specifies the format an email address
-		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9\.\!\#\$\%\&\'\*\+\-\/\=\?\^\_\`\{\|\}\~])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$|^\[[^\]]+\]$/i);
+		var filter = new RegExp(/^([^<]*<){0,1}( *([a-z0-9\.\!\#\$\%\&\'\*\+\-\/\=\?\^\_\`\{\|\}\~])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+) *>{0,1}$|^\[[^\]]+\]$/i);
 		if(email.length > 0 && !filter.test(email)){
 			result += "\n"+email;
 		}
@@ -660,7 +660,7 @@ function parseEmailAddress(address)
 	// here is the modified one. The only difference is that it discards
 	// quotes and spaces from the fullname
 	
-	var filter = new RegExp(/^("?([^<"]*)"? ?<){0,1}(([a-z0-9=_\+\.\-])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$/i); 
+	var filter = new RegExp(/^("?([^<"]*)"? ?<){0,1}( *([a-z0-9=_\+\.\-])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+) *>{0,1}$/i); 
 	
 	// It also breaks coloring in my editor, so here is a quote to stop the runaway string "
 	
@@ -671,6 +671,12 @@ function parseEmailAddress(address)
 		result = new Object;
 		result.displayname = matches[2];
 		result.emailaddress = matches[3];
+
+		if(result.displayname)
+			result.displayname = result.displayname.trim();
+		if(result.emailaddress)
+			result.emailaddress = result.emailaddress.trim();
+
 	} else {
 		result = false;
 	}	
@@ -681,7 +687,7 @@ function parseEmailAddress(address)
 
 function iconIndexToClassName(icon_index,messageClass, isRead, isStub)
 {
-	if(isStub)
+	if(isStub && parseInt(isStub,10))
 		return "icon_stubbed";
 
 	var className = "";
@@ -958,9 +964,11 @@ function convertAnchors(content)
 
 function removeTagFromSource(content, tagName, closingTag, saveDocOnNoClosingTag){
 	var openIndex, closeIndex;
-	while((openIndex = content.search(new RegExp("<"+tagName, "gim"))) && openIndex >= 0){
+	// We look for the tag that matches tagName exactly. The "[ >]" at the end of the RegExp will 
+	// match <head> or <head arg="1">, but will not match <header>.
+	while((openIndex = content.search(new RegExp("<"+tagName+"[ >]", "gim"))) && openIndex >= 0){
 		if(closingTag){
-			closeIndex = content.search(new RegExp("</"+tagName, "gim"))
+			closeIndex = content.search(new RegExp("</"+tagName+"[ >]", "gim"))
 			if(closeIndex >= 0){
 				closeIndex = content.indexOf(">", closeIndex) + 1;
 			// No closing tag found, use end of string
@@ -1728,21 +1736,25 @@ function getTaskRecurrencePattern(recurr)
 }
 
 /**
- * Funtion recursively scans dom to get text nodes which contain email address so we can replace it with
- * anchor tag.
+ * Funtion recursively scans dom to get text nodes which contain email addresses or URLs so we can 
+ * replace them with an anchor tag.
+ * @param HTMLElement node The parent node that will be examined to find the child text nodes
  */
-function scanDOM(node) {
+function linkifyDOM(node){
+	var emailPattern = /([a-z0-9_'+*$%\^&!\.\-]+\@(?:[a-z0-9\-]+\.)+[a-z]{2,})/gi;
+	var linkPattern = /((ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?)/gi;
+
 	for(var i = 0; i < node.childNodes.length; i++) {
 		var cnode = node.childNodes[i];
 		if(cnode.nodeType == 1) { // Tag-node
 			if(cnode.nodeName != 'A') {
-				scanDOM(cnode);
+				linkifyDOM(cnode);
 			}
 		} else if(cnode.nodeType == 3) { // Text-node
 			if(cnode.nodeValue.trim().length > 0) {
 				// check if this text node is email address
-				if(cnode.nodeValue.search(/[a-z0-9_'+*$%\^&!\.\-]+\@(?:[a-z0-9\-]+\.)+[a-z]{2,}/gi) != -1) {
-					addEmailLinks(cnode, node);
+				if(cnode.nodeValue.search(emailPattern) != -1 || cnode.nodeValue.search(linkPattern) != -1) {
+					linkifyDOMNode(cnode, node);
 				}
 			}
 		}
@@ -1751,19 +1763,105 @@ function scanDOM(node) {
 
 /**
  * Function will replace text nodes with element nodes which contains anchor tag.
+ * @param HTMLElement node The node that has to be examined for links or emails
+ * @parem HTMLElement parentNode The parent of the passed node
  */
-function addEmailLinks(node, parentNode) {
-	var clonedTextNode = node.cloneNode(false);
+function linkifyDOMNode(node, parentNode) {
+	var linkPattern = /((ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?)/gi;
+	var emailPattern = /([a-z0-9_'+*$%\^&!\.\-]+\@(?:[a-z0-9\-]+\.)+[a-z]{2,})/gi;
 
-	// Create a new anchor-node.
-	var anchorNode = dhtml.addElement(null, 'a');
-	anchorNode.setAttribute('href', 'mailto: ' + clonedTextNode.nodeValue);
-	anchorNode.setAttribute('target', '_blank');
-	anchorNode.setAttribute('onclick', 'parent.webclient.openWindow(this, "createmail", "index.php?load=dialog&task=createmail_standard&to=' + clonedTextNode.nodeValue + '"); return false;');
+	var str = node.nodeValue;
 
-	// Add text node to the new anchor node.
-	anchorNode.appendChild(clonedTextNode);
+	// Split the strings up in pieces that are normal text and pieces that contain an URL
+	// We do this before checking for email addresses as an ftp-URL with username/password within will otherwise be seen as an email address
+	var lookupParts = splitStringByPattern(str, linkPattern);
+	var parts = [];
+	// Now loop through all the pieces split them up based on whether they contain an email address
+	for(var i=0;i<lookupParts.length;i++){
+		// Do not examine an piece that already contains a link
+		if(lookupParts[i].search(linkPattern) == -1){
+			// Spit the pieces up based on whether they contain a link
+			var tmpParts = splitStringByPattern(lookupParts[i], emailPattern);
+			parts.push.apply(parts, tmpParts);
+		}else{
+			parts.push(lookupParts[i]);
+		}
+	}
 
-	// Replace the original text node under the parent with the new anchorNode.
-	parentNode.replaceChild(anchorNode, node);
+	// Create a container node to append all the textnodes and anchor nodes to
+	var containerNode = dhtml.addElement(null, 'span');
+	for(var i=0;i<parts.length;i++){
+		// Create the node for a normal link
+		if(parts[i].search(linkPattern) != -1){
+			// Create a new anchor-node.
+			var anchorNode = dhtml.addElement(containerNode, 'a');
+			anchorNode.setAttribute('href', parts[i]);
+			anchorNode.setAttribute('target', '_blank');
+
+			// Add text node to the new anchor node.
+			dhtml.addTextNode(anchorNode, parts[i]);
+		// Create the node for an email link
+		}else if(parts[i].search(emailPattern) != -1){
+			// Create a new anchor-node.
+			var anchorNode = dhtml.addElement(containerNode, 'a');
+			anchorNode.setAttribute('href', 'mailto: ' + parts[i]);
+			anchorNode.setAttribute('target', '_blank');
+			anchorNode.setAttribute('onclick', 'parent.webclient.openWindow(this, "createmail", "index.php?load=dialog&task=createmail_standard&to=' + parts[i] + '"); return false;');
+
+			// Add text node to the new anchor node.
+			dhtml.addTextNode(anchorNode, parts[i]);
+		// Just text, so lets make a text node
+		}else{
+			dhtml.addTextNode(containerNode, parts[i]);
+		}
+	}
+
+	// Replace the original text node under the parent with the new anchor nodes and split up text nodes.
+	for(var i=0, count=containerNode.childNodes.length;i<count;i++){
+		// We remove the childNode from the parent by using this line so every loop we can add the first as the list shrinks
+		parentNode.insertBefore(containerNode.childNodes.item(0), node);
+	}
+	// Remove the original node
+	parentNode.removeChild(node);
+}
+
+/** 
+ * Split a string in pieces based on whether each piece matches the passed 
+ * pattern. It returns both the pieces that match and that do not match the 
+ * pattern. 
+ * @param String str The input string to be split up
+ * @param RegExp pattern The regex pattern used to be split the string
+ * @return Array The array of pieces
+ */
+function splitStringByPattern(str, pattern){
+	var parts = [];
+	var cutOffPoints = [0];
+	var found;
+	// Find the cutOffPoints in the str
+	while((found = pattern.exec(str)) !== null){
+		if(found.index!=0){
+			cutOffPoints.push(found.index);
+		}
+		if(pattern.lastIndex < str.length){
+			cutOffPoints.push(pattern.lastIndex);
+		}
+	}
+	// Cut the string up into the pieces based on the cutOffPoints
+	var parts = [];
+	if(cutOffPoints.length > 1){
+		for(var i=0;i<cutOffPoints.length;i++){
+			var length;
+			// Use the current and the next cutOffPoint to calculate the number of character we need to extract.
+			if(cutOffPoints[i+1] != undefined){
+				length = cutOffPoints[i+1]-cutOffPoints[i];
+			// If there is no next cutOffPoint we have to calculate the number of characters using the length of the entire string
+			}else{
+				length = str.length - cutOffPoints[i];
+			}
+			parts.push(str.substr(cutOffPoints[i], length));
+		}
+	}else{
+		parts = [str];
+	}
+	return parts;
 }
\ No newline at end of file
