@@ -93,6 +93,12 @@ WebClient.prototype.init = function(base_url, modulePrefix, availableModules, se
 	this.pluginManager.init();
 
 	startKeepAlive();
+
+    /*
+     * Trigger the hook so it is possible to execute code directly after the webclient
+     * has finished initializing.
+     */
+    webclient.pluginManager.triggerHook('client.core.webclient.init.after', {});
 }
 
 WebClient.prototype.setUserInfo = function(username, fullname, entryid, emailaddress)
@@ -400,27 +406,6 @@ WebClient.prototype.getModulesByName = function(moduleName)
 	return modules;
 }
 
-/**
- * Function which returns a store from list of MUC store
- *
- * @param string storeid the storeid
- * @return mucStore store object
- */
-WebClient.prototype.getMUCStore = function(storeid)
-{
-	var mucStore = false;
-
-	if (this.groups && typeof this.groups == "object"){
-		for(var store in this.groups){
-			if(this.groups[store].storeid == storeid) {
-				mucStore = this.groups[store];
-			}
-		}
-	}
-
-	return mucStore;
-}
-
 /**
  * Function which adds a module to the modules list.
  * @param object module module object
