@@ -175,7 +175,14 @@
 						// Open the already saved attachment
 						$attachment = mapi_message_openattach($message, (int) $attachNum[(count($attachNum) - 1)]);
 					}
-				} else if($attachCid) { // Check if attachCid isset
+				}
+				
+				if($attachCid) { // Check if attachCid isset
+					// If the inline image was in a submessage, we have to open that first
+					if($attachment) {
+						$message = mapi_attach_openobj($attachment);
+					}
+					
 					// Get the attachment table
 					$attachments = mapi_message_getattachmenttable($message);
 					$attachTable = mapi_table_queryallrows($attachments, Array(PR_ATTACH_NUM, PR_ATTACH_CONTENT_ID, PR_ATTACH_CONTENT_LOCATION, PR_ATTACH_FILENAME));
@@ -191,11 +198,11 @@
 						}
 					}
 				}
-				
+
 				// Check if the attachment is opened
 				if($attachment) {
 					// Get the props of the attachment
-					$props = mapi_attach_getprops($attachment, array(PR_ATTACH_LONG_FILENAME, PR_ATTACH_MIME_TAG, PR_DISPLAY_NAME, PR_ATTACH_METHOD));
+					$props = mapi_attach_getprops($attachment, array(PR_ATTACH_FILENAME, PR_ATTACH_LONG_FILENAME, PR_ATTACH_MIME_TAG, PR_DISPLAY_NAME, PR_ATTACH_METHOD));
 
 					// Content Type
 					$contentType = "application/octet-stream";
@@ -339,15 +346,15 @@
 		}
 
 		//create a zip file name from subject or from date.
-		$fileName = ($mailSubject) ? $mailSubject : date("h_i_s-j_m_Y");
+		$fileName = ( ($mailSubject) ? $mailSubject : date("h_i_s-j_m_Y") ) . '.zip';
 
 		// download the created zip file.
-		$zipName = TMP_PATH . "/" . $fileName . ".zip";
+		$zipName = TMP_PATH . "/" . $fileName;
 		
 		$zipFile = fopen($zipName, "wb");
 		$out = fwrite($zipFile, $createZipFile->getZippedfile());
 		fclose($zipFile);
-		$createZipFile->forceDownload($zipName);
+		$createZipFile->forceDownload($zipName, $fileName);
 		@unlink($zipName);
 	}
 
