@@ -77,12 +77,14 @@ function getJavaScript_onload(){ ?>
 					data["type"] = "<?=get("type","fullemail", false, STRING_REGEX)?>";
 					data["source"] = "<?=get("source", "all", false, STRING_REGEX)?>"; // possible values: all, gab
 					data["showsendmail"] = "<?=get("showsendmail","false", false, STRING_REGEX)?>"; // Show button for sending mail in addressbook.
+					data["detailsonopen"] = ("<?=get("detailsonopen","false", false, STRING_REGEX)?>"=="true"); // Opens the GAB details when opening the GAB details
 
 					if(typeof window.windowData != "undefined") {
 						// for GAB & addresslists
 						data["hide_companies"] = window.windowData["hide_companies"] || false;		// true, false
 						data["hide_users"] = window.windowData["hide_users"] || false;				// active, non_active, room, equipment, contact, system
 						data["hide_groups"] = window.windowData["hide_groups"] || false;			// normal, security, dynamic, everyone
+						data["detailsonopen"] = window.windowData["detailsonopen"] || data["detailsonopen"];	// Opens the GAB details when opening the GAB details, can override the setting of the URL
 					} else {
 						// for contacts folders
 						data["groups"] = "<?=get("groups", "yes", false, STRING_REGEX)?>";			// yes, no
@@ -201,7 +203,7 @@ function getBody(){ ?>
 				</tr>
 			</table>
 			
-			<div id="items" onmousedown="return false;">
+			<div id="items" onmousedown="return eventCheckScrolling(event);">
 				
 			</div>
 			
