@@ -57,13 +57,21 @@ function getDialogTitle() {
 
 // Include SWFUpload library.
 function getIncludes(){
-	return array(
-			"client/layout/js/attachments.js",
+	$includes = array(
+			"client/layout/js/attachments.js");
+			
+	$swfupload = array(
 			"client/widgets/swfupload/swfupload.js",
 			"client/widgets/swfupload/swfupload.queue.js",
 			"client/widgets/swfupload/swfupload.cookies.js",
 			"client/widgets/swfupload/swfupload.swfobject.js"
 		);
+		
+	if(ENABLE_MULTI_UPLOAD) {
+		return array_merge($includes,$swfupload);
+	} else {
+		return $includes;
+	}
 }
 
 function getJavaScript_onload(){ ?>
@@ -173,6 +181,10 @@ function getJavaScript_onload(){ ?>
 					}
 
 					var enableMultiUpload = <?=ENABLE_MULTI_UPLOAD ? 'true' : 'false'?>;
+					
+					// Non-IE browsers do not use the flash uploader since it has various issues
+					if(!window.BROWSER_IE)
+						enableMultiUpload = false;
 					initUploadObject(enableMultiUpload);
 
 					webclient.menu.showMenu();
@@ -181,7 +193,7 @@ function getJavaScript_onload(){ ?>
 function getJavaScript_other(){ ?>
 		var uploadObj;
 		var FILE_UPLOAD_LIMIT = <?= defined('FILE_UPLOAD_LIMIT') ? FILE_UPLOAD_LIMIT : 50 ?>;
-		var FILE_QUEUE_LIMIT = <?= defined('FILE_QUEUE_LIMIT') ? FILE_QUEUE_LIMIT : 50 ?>;
+		var FILE_QUEUE_LIMIT = <?= GetMaxFileUploads() ?>;
 		function checkAttachmentList(){
 			// Check whether there are any files uploaded or, in upload queue.
 			if(dhtml.getElementById('filelist').options.length == 0 && totalFiles == 0)
@@ -193,7 +205,7 @@ function getJavaScript_other(){ ?>
 			if (totalFiles > uploadedFiles){
 				// Update attachments list in attachment-bar of parentwindow.
 				parentwindow.module.getAttachments();
-				return "<?=_("All files are not uploaded yet. If you continue, you will lose some attachments.")?>";
+				return "<?=_("Not all attachments have been uploaded. If you continue some attachments may be omitted.")?>";
 			}
 		}
 		/**
@@ -248,38 +260,6 @@ function getJavaScript_other(){ ?>
 			}
 			location.href = downloadAllAttachmentsUri;
 		}
-		/**
-		 * Function which download attachment(s)
-		 * @param boolean downloadAllFlag Flag if true represents to download all messages else download only one.
-		 */
-		function downloadAttachments(downloadAllFlag){
-			var downloadAllAttachmentsUri = 'index.php?load=download_attachment';
-			downloadAllAttachmentsUri += '&store=<?=htmlentities(get("store", false, false, ID_REGEX))?>';
-			downloadAllAttachmentsUri += '&entryid=<?=htmlentities(get("entryid", false, false, ID_REGEX))?>';
-			downloadAllAttachmentsUri += '&openType=attachment';
-			downloadAllAttachmentsUri += '&dialog_attachments=<?=htmlentities($_REQUEST["dialog_attachments"])?>';
-			if(downloadAllFlag){
-				downloadAllAttachmentsUri += '&downloadType=downloadAll';
-				// add the subject part
-				var subject = parentwindow.module.itemProps.subject || (window.opener.dhtml.getElementById("subject").value || '');
-				downloadAllAttachmentsUri += '&mailSubject=' + subject.replace(/\s/g, '_').substring(0, 20);
-
-				// add all attachNum to url
-				var downAttachElemOpt = dhtml.getElementById('filelist').options;
-				for(var j = 0; j < downAttachElemOpt.length; j++){
-					downloadAllAttachmentsUri += '&attachNum[]=' + downAttachElemOpt[j].value;
-				}
-			}else{
-				var fileList = dhtml.getElementById('filelist');
-				if(fileList.selectedIndex >= 0){
-					downloadAllAttachmentsUri += '&attachNum[]=' + fileList.options[fileList.selectedIndex].value;
-				}else{
-					alert(_("Please select a file to download") + ".");
-					return;
-				}
-			}
-			location.href = downloadAllAttachmentsUri;
-		}
 <? } // javascript other
 
 function getBody(){ ?>
@@ -301,8 +281,8 @@ function getBody(){ ?>
 					<div id="normal-upload-control">
 						<dl>
 							<dt><label for="attachment"><?=_("Filename")?>:</label></dt>
-							<dd><input type="file" multiple id="attachment" name="attachments[]" onchange="dhtml.getElementById('upload').submit();" /></dd>
-							<dd> (<?= _("max filesize") ?>: <?= getMaxUploadSize(true) ?>)</dd>
+							<dd><input type="file" multiple id="attachment" name="attachments[]" onchange="onChangeAttachment();" /></dd>
+							<dd class="filesize_block"> (<?= _("max filesize") ?>: <?= getMaxUploadSize(true) ?>)</dd>
 						</dl>
 					</div>
 
@@ -322,7 +302,7 @@ function getBody(){ ?>
 						<div class="attach_buttons">
 								<input id="delete" class="button_delete" type="button" value="<?=_("Delete")?>" title="<?=_("Delete selected file")?>" onclick="dhtml.getElementById('action').submit();" /><br/>
 								<input id="save" class="button_save" type="button" value="<?=_("Download")?>" title="<?=_("Download selected file")?>" onclick="downloadAttachments(false)" />
-								<input id="saveall" class="button_save" type="button" value="<?=_("Download All")?>" title="<?=_("Download All Attachments as a zip archive")?>" onclick="downloadAttachments(true)" />
+								<input id="saveall" class="button_save" type="button" value="<?=_("Download All")?>" title="<?=_("Download all attachments as a zip archive")?>" onclick="downloadAttachments(true)" />
 								<input type="hidden" name="dialog_attachments" value="<?=$_REQUEST["dialog_attachments"]?>" />
 								<input id="deleteattachment" type="hidden" name="deleteattachment" value="" />
 								<input id="type" type="hidden" name="type" value="" />
