@@ -110,7 +110,7 @@ function getJavaScript_other(){ ?>
 				var target_store = module.selectedFolderStoreId;
 				
 				if(!target_entryid){
-					alert("<?=_("Please select the destination Folder to copy/move selected message/s")?>");
+					alert("<?=_("Please select the destination folder to copy or move the selected message(s) to.")?>");
 				}else if(compareEntryIds(target_entryid, module.defaultstore.root.entryid)){
 					// this check whether the target folder is a root folder or not
 					alert("<?=_("Cannot move the items. The destination folder cannot contain messages/forms.")?>");
