@@ -55,7 +55,7 @@ function getModuleType(){
 }
 
 function getDialogTitle(){
-	return _("Customize Webaccess Today");
+	return _("Customize WebAccess Today");
 }
 
 function getIncludes(){
@@ -77,12 +77,12 @@ function getBody() {
 		<div class="customize">
 				
 			<fieldset class="customizetoday_fieldset">
-				<legend><?=_("Calender")?></legend>
+				<legend><?=_("Calendar")?></legend>
 				
 				<table border="0" cellpadding="1" cellspacing="0">
 					<tr>
 						<td class="">
-							<?=_("Show this number of days in my calender")?> : &nbsp;
+							<?=_("Show this number of days in my calendar")?> : &nbsp;
 						</td>
 						<td>
 							<select id="select_days" class="combobox" onchange="onChangeDays();">
@@ -121,7 +121,7 @@ function getBody() {
 				<table border="0" cellpadding="1" cellspacing="0">
 					<tr>
 						<td class="">
-							<?=_("Show Outlook Today in this style")?> : &nbsp;
+							<?=_("Show WebAccess Today in this style")?> : &nbsp;
 						</td>
 						<td>
 							<select id="select_styles" class="combobox" onchange="onChangeStyles();">
