@@ -94,7 +94,7 @@ function getJavaScript_other(){ ?>
 <?php } // getJavaScript_other
 	
 function getBody() { ?>
-	<span><?= _("The Webaccess") ?> <?= _("found more than one") ?> 
+	<span><?= _("The WebAccess") ?> <?= _("found more than one") ?> 
 		"<span id="search_key"><?=isset($_GET["keyword"])?htmlentities(get("keyword", false, false, STRING_REGEX)):''; ?></span>".
 	</span>
 	<br>
