@@ -132,7 +132,7 @@ function getBody(){
 		</dl>
 		<div id="subfolders">
 			<input type="checkbox" id="subfolders_checkbox" disabled>
-			<label id="subfolders_label" class="disabled_text" for="subfolders_checkbox"><?=("Search subfolders")?></label>
+			<label id="subfolders_label" class="disabled_text" for="subfolders_checkbox"><?=_("Search subfolders")?></label>
 		</div>
 
 		<?=createConfirmButtons("if(submitFolder()) window.close; else window.focus();")?>
