@@ -82,7 +82,7 @@ function getBody(){ ?>
 					<td colspan="2">
 						<input type="checkbox" id="subfolders_checkbox"></input>
 						<label id="subfolders_label" for="subfolders_checkbox">
-							<?=("Show subfolders")?>
+							<?=_("Show subfolders")?>
 						</label>
 					</td>
 				</tr>
