@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -61,9 +63,14 @@ function calendar_loadSettings(settings){
 	field = dhtml.getElementById("calendar_size");
 	field.value = parseInt(value);
 
+	value = settings.get("calendar/appointment_time_size", 2);
+	field = dhtml.getElementById("calendar_appointment_size");
+	field.value = parseInt(value);
+
 	value = settings.get("calendar/mucalendar/zoomlevel", 3);
 	field = dhtml.getElementById("calendar_mucalendar_zoomlevel");
 	field.value = parseInt(value);
+
 	value = settings.get("calendar/mucalendar/numofdaysloaded", 5);
 	field = dhtml.getElementById("calendar_mucalendar_numofdaysloaded");
 	field.value = parseInt(value);
@@ -86,28 +93,68 @@ function calendar_saveSettings(settings){
 	var value;
 	var field;
 
+	old_value = settings.get("calendar/workdaystart",9*60);
 	field = dhtml.getElementById("calendar_workdaystart");
 	settings.set("calendar/workdaystart",field.value);
+	if (old_value != field.value){
+		reloadNeeded = true;
+	}
+
+	old_value = settings.get("calendar/workdayend",17*60);
 	field = dhtml.getElementById("calendar_workdayend");
 	settings.set("calendar/workdayend",field.value);
+	if (old_value != field.value){
+		reloadNeeded = true;
+	}
+	
+	old_value = settings.get("calendar/vsize", 2);
 	field = dhtml.getElementById("calendar_size");
 	settings.set("calendar/vsize",parseInt(field.value));
+	if (old_value != parseInt(field.value)){
+		reloadNeeded = true;
+	}
 
+	old_value = settings.get("calendar/appointment_time_size", 2);
+	field = dhtml.getElementById("calendar_appointment_size");
+	settings.set("calendar/appointment_time_size",parseInt(field.value));
+	if (old_value != parseInt(field.value)){
+		reloadNeeded = true;
+	}
+
+	old_value = settings.get("calendar/mucalendar/zoomlevel", 3);
 	field = dhtml.getElementById("calendar_mucalendar_zoomlevel");
 	settings.set("calendar/mucalendar/zoomlevel",parseInt(field.value));
+	if (old_value != parseInt(field.value)){
+		reloadNeeded = true;
+	}
+	
+	old_value = settings.get("calendar/mucalendar/numofdaysloaded", 5);
 	field = dhtml.getElementById("calendar_mucalendar_numofdaysloaded");
 	settings.set("calendar/mucalendar/numofdaysloaded",parseInt(field.value));
+	if (old_value != parseInt(field.value)){
+		reloadNeeded = true;
+	}
 
+	old_value = settings.get("calendar/reminder","true");
 	field = dhtml.getElementById("calendar_reminder");
 	settings.set("calendar/reminder",field.checked?"true":"false");
+	if (old_value != (field.checked?"true":"false")){
+		reloadNeeded = true;
+	}
 
+	old_value = settings.get("calendar/reminder_minutes", 15);
 	field = dhtml.getElementById("calendar_reminder_minutes");	
 	settings.set("calendar/reminder_minutes",parseInt(field.value));
+	if (old_value != parseInt(field.value)){
+		reloadNeeded = true;
+	}
 
+	old_value = settings.get("calendar/calendar_refresh_button", "true");
 	field = dhtml.getElementById("calendar_refresh_button");	
 	settings.set("calendar/calendar_refresh_button", (field.checked)?"true":"false");
-
-	reloadNeeded = true;
+	if (old_value != (field.checked?"true":"false")){
+		reloadNeeded = true;
+	}
 }
 
 function calendar_checkworkhours(element)
@@ -155,4 +202,18 @@ function calendar_checkremindersetting(element)
 			select_reminder_minutes.style.background = "#DFDFDF";
 		}
 	}
+}
+
+function calendar_checkcalendarcellsize(element)
+{
+	var checkbox_size = dhtml.getElementById("calendar_size");
+	var calendar_appointment_size = dhtml.getElementById("calendar_appointment_size");
+	
+	if(checkbox_size.value == 1){
+		if(calendar_appointment_size.value == 1){
+			alert(_("This combination of Vertical Size and Calendar resolution is invalid"));
+			checkbox_size.value = webclient.settings.get("calendar/vsize", 2);
+			calendar_appointment_size.value = webclient.settings.get("calendar/appointment_time_size", 2);
+		}
+	}
 }
\ No newline at end of file
