@@ -75,7 +75,7 @@ function preferences_loadSettings(settings){
 	}
 	
 	// theme
-	value = settings.get("global/theme_color", "default");
+	value = settings.get("global/theme_color", "white");
 	field = dhtml.getElementById("preferences_theme");
 	for(var i = 0; i<field.length; i++){
 		if (field.options[i].value == value){
@@ -161,7 +161,7 @@ function preferences_saveSettings(settings){
 	}
 
 	// theme (check if changed => reload)
-	old_value = settings.get("global/theme_color", "default");
+	old_value = settings.get("global/theme_color", "white");
 	field = dhtml.getElementById("preferences_theme");
 	settings.set("global/theme_color",field.options[field.selectedIndex].value);
 	if (old_value != field.options[field.selectedIndex].value){
