@@ -60,13 +60,13 @@ function vacation_loadSettings(settings){
 	vacation_signableChange();
 
 	// subject, set with default value
-	value = settings.get("outofoffice/subject",_("Out of Office"));
+	value = settings.get("outofoffice/subject", _("Out of Office") );
 	field = dhtml.getElementById("vacation_subject");
 	field.value = value;
 
 
 	// message, set with default value
-	value = settings.get("outofoffice/message",_("User is currently out of office")+".");
+	value = settings.get("outofoffice/message", _("User is currently out of office") +".");
 	field = dhtml.getElementById("vacation_message");
 	field.value = value;
 }
@@ -77,6 +77,8 @@ function vacation_saveSettings(settings){
 	// signable
 	field = dhtml.getElementById("vacation_signable");
 	settings.set("outofoffice/set",field.checked?"true":"false");
+	// Store current sessionid in settings, to get when setting for out of office was saved.
+	settings.set("outofoffice_change_id", parentWebclient.sessionid);
 
 	// subject
 	field = dhtml.getElementById("vacation_subject");
