@@ -161,6 +161,12 @@ function getJavaScript_onload(){
 					if(cancelinviteattendeesbutton) {
 						cancelinviteattendeesbutton.style.display = "none";
 					}
+
+					// Hide print button for new apointments and MRs
+					var printButton = dhtml.getElementById("print");
+					if(printButton) {
+						printButton.style.display = "none";
+					}
 					
 					if (window.location.search.indexOf("meeting=true")>0){
 						meetingRequestSetup(mrSetupOrganiser);
@@ -225,6 +231,13 @@ function getJavaScript_onload(){
 						module.setBodyFromItemData(window.windowData["data"]);
 					}
 
+					// set focus on appointment dialogs
+					if (window.location.search.indexOf("meeting=true")>0)
+						// set focus on to field if meeting
+						dhtml.getElementById("toccbcc").focus();
+					else
+						// set focus on subject field if normal appointment
+						dhtml.getElementById("subject").focus();
 <?php } // getJavaScript_onload						
 					
 function getBody() { 
@@ -354,15 +367,15 @@ function getBody() {
 						<select id="select_label" class="combobox" style="width:94%;">
 							<option value="0" class="label_none" selected><?=_("None")?></option>
 							<option value="1" class="label_important"><?=_("Important")?></option>
-							<option value="2" class="label_work"><?=_("Work")?></option>
+							<option value="2" class="label_work"><?=_("Business")?></option>
 							<option value="3" class="label_personal"><?=_("Personal")?></option>
-							<option value="4" class="label_holiday"><?=_("Holiday")?></option>
-							<option value="5" class="label_required"><?=_("Required")?></option>
+							<option value="4" class="label_holiday"><?=_("Vacation")?></option>
+							<option value="5" class="label_required"><?=_("Must Attend")?></option>
 							<option value="6" class="label_travel_required"><?=_("Travel Required")?></option>
-							<option value="7" class="label_prepare_required"><?=_("Prepare Required")?></option>
+							<option value="7" class="label_prepare_required"><?=_("Needs Preparation")?></option>
 							<option value="8" class="label_birthday"><?=_("Birthday")?></option>
-							<option value="9" class="label_special_date"><?=_("Special Date")?></option>
-							<option value="10" class="label_phone_interview"><?=_("Phone Interview")?></option>
+							<option value="9" class="label_special_date"><?=_("Anniversary")?></option>
+							<option value="10" class="label_phone_interview"><?=_("Phone Call")?></option>
 						</select>
 					</td>
 				</tr>
@@ -450,7 +463,7 @@ function getBody() {
 			<table width="99%" border="0" cellpadding="1" cellspacing="0">
 				<tr>
 					<td class="propertynormal propertywidth" valign="top">
-						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
+						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');">
 					</td>
 					<td valign="top">
 						<div id="itemattachments">&nbsp;</div>
@@ -568,15 +581,14 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
+				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 570, 425, '0');}"
 			),
-/* Disable Attach item
 			array(
 				'id'=>"attach_item",
 				'name'=>"",
 				'title'=>_("Attach item"),
 				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
-			), */
+			),
 			array(
 				'id'=>"seperator",
 				'name'=>"",
@@ -599,7 +611,7 @@ function getMenuButtons(){
 				'id'=>"recurrence",
 				'name'=>_("Recurrence"),
 				'title'=>_("Recurrence"),
-				'callback'=>"function(){webclient.openModalDialog(module, 'recurrence', DIALOG_URL+'task=recurrence_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, callBackRecurrence);}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'recurrence', DIALOG_URL+'task=recurrence_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 405, callBackRecurrence);}"
 			),
 			array(
 				'id'=>"seperator2",
