@@ -412,6 +412,7 @@ function getJavaScript_other(){
 				 * Also added few events for handling shortcuts in FCKeditor. DHTML version could be used by that doesnt
 				 * work so adding events using attachEvent/addEventListener.
 				 */
+				var iframeWindow = dhtml.getElementById("html_body___Frame").contentWindow.document.getElementsByTagName('iframe')[0].contentWindow;
 				if (window.BROWSER_IE) {
 					editorInstance.EditorDocument.attachEvent("onkeydown", IE_tracCursorInEditor);
 					editorInstance.EditorDocument.attachEvent("onmousedown", IE_tracCursorInEditor);
@@ -424,8 +425,8 @@ function getJavaScript_other(){
 					editorInstance.EditorDocument.attachEvent("onkeydown", handleFCKeditorEvent);
 				} else {
 					// Events for shortcuts
-					editorInstance.EditorDocument.addEventListener("keydown", handleFCKeditorEvent, true);
-					editorInstance.EditorDocument.addEventListener("keyup", handleFCKeditorEvent, true);
+					iframeWindow.addEventListener("keydown", handleFCKeditorEvent, true);
+					iframeWindow.addEventListener("keyup", handleFCKeditorEvent, true);
 				}
 			}
 			
