@@ -82,6 +82,10 @@
 		<br>&nbsp; <!-- HACK -->
 	</div>
 	<div id="fbstartdate"></div>
+	<div id="fballday">					
+		<input id="checkbox_allday" type="checkbox" onclick="fb_module.onChangeAllDay();">
+		<label for="checkbox_allday"><?=_("All Day Event")?></label>
+	</div>
 	<div id="fbenddate"></div>
 	<div id="fbrecur" style="display: none">
 		<p>
