@@ -96,6 +96,9 @@ function getJavaScript_onload(){ ?>
 					if(window.windowData && window.windowData["action"] == "convert_item") {
 						module.sendConversionItemData(windowData);
 					}
+
+					//set focus on body of the note
+					dhtml.getElementById("html_body").focus();
 <?php } // getJavaSctipt_onload
 			
 function getBody() { ?>
