@@ -82,6 +82,13 @@
 		<link rel="stylesheet" type="text/css" href="client/layout/css/style.ie.css">
 		<![endif]-->
 <?php
+	// Apply an iPad specific stylesheet when needed
+	if(strpos($_SERVER['HTTP_USER_AGENT'], 'iPad') !== false){
+?>
+		<link rel="stylesheet" type="text/css" href="client/layout/css/style.ipad.css">
+<?php
+	}
+
 	$pluginCSSFiles = $GLOBALS['PluginManager']->getClientFiles('css', Array('all','dialog'));
 	if(count($pluginCSSFiles) > 0){
 		includeFiles('css', $pluginCSSFiles);
@@ -178,6 +185,10 @@
 			var module;
 			var dialoghelper;
 			var BASE_URL = "<?=BASE_URL?>";
+			var NAMEDPROPS = {
+				'PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords' : "<?=convertStringToHexNamedPropId('PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords')?>",
+				'PT_STRING8:PS_PUBLIC_STRINGS:Keywords' : "<?=convertStringToHexNamedPropId('PT_STRING8:PS_PUBLIC_STRINGS:Keywords')?>"
+			};
 			
 			window.onload = function()
 			{
@@ -277,8 +288,31 @@
 					data["plugin"] = <?=(($plugin)?'"'.$plugin.'"':"false")?>;
 					webclient.pluginManager.triggerHook("client.dialog.general.onload.after", data);
 				}
+
+				/**
+				 * Set height of the dialog, If content of the dialog is not shown completely
+				 * in the view, Suggest height of the dialog according to the content's
+				 * position in the dialog, Add 10 pixels for better view.
+				 */
+				var dialog_content = dhtml.getElementById("dialog_content");
+				var suggestedHeight = dialog_content.offsetTop + dialog_content.clientHeight + 10;
+				var browserInnerSize = dhtml.getBrowserInnerSize();
+
+				/**
+				 * Change(Increase) height of the dialog only if height of the dialog is
+				 * lesser then the suggest height, It should be possible to set deliberately
+				 * more height for the dialog. And moreover this won't affect the dialogs
+				 * which are working fine.
+				 */
+				if(browserInnerSize.y < suggestedHeight){
+					if(window.dialogHeight) { // for modal dialogs in IE.
+						window.dialogHeight = suggestedHeight + 'px';
+					}else if(window.resizeBy){
+						window.resizeBy(0, suggestedHeight - browserInnerSize.y);
+					}
+				}
 			}
-			
+
 			window.onresize = function()
 			{
 				if(webclient){
