@@ -268,7 +268,7 @@ function advFindRenderRowColumnData(moduleObject, itemData, properties) {
 				} else {
 					var folderName = NBSP;
 				}
-				value = folderName;
+				value = folderName.htmlEntities();
 				break;
 			case "alldayevent":
 				var checked = "";
@@ -419,8 +419,8 @@ function advFindRenderRowColumnData(moduleObject, itemData, properties) {
 					value = strftime(_("%a %x %X"), xmlValue);
 				} else if(xmlNode && xmlNode.getAttribute("type") == "timestamp_date") {
 					value = strftime_gmt(_("%a %x %X"), xmlValue);
-				} else if(typeof xmlValue != null) {
-					value = xmlValue;
+				} else if(typeof xmlValue == "string") {
+					value = xmlValue.htmlEntities();
 				} else {
 					value = NBSP;
 				}
