@@ -432,6 +432,7 @@ function submitAppointment(send, requestStatus)
 		module.setEndTime(fb_module.getEndMeetingTime());
 		module.setLocation(fb_module.getResource());
 		module.setUserList(fb_module.getUserList());
+		module.setAllDayEvent(fb_module.isAllDayEvent());
 	}
 
 	// Label
@@ -530,8 +531,6 @@ function submitAppointment(send, requestStatus)
 			// Check whether there are any recepients in MR or not.
 			if( endtime>(new Date().getTime()) && recepientsList.length > 0) {
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
-
-				if (!send) return false;
 			}
 		}
 	} else if (recepientsList.length == 0) {
@@ -682,8 +681,7 @@ function deleteAppointment()
 	var basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
 	basedate = basedate ? parseInt(basedate, 10) : 0;
 
-	if (!module.deleteMessage(basedate))
-		window.close();
+	module.deleteMessage(basedate);
 }
 
 function onChangeReminder()
@@ -881,6 +879,7 @@ function onAppointmentTabChange(newTab,oldTab)
 		//update the meetingtime in freebusy tab
 		fb_module.setStartMeetingTime(module.getStartTime());
 		fb_module.setEndMeetingTime(module.getEndTime());
+		fb_module.setAllDayEvent(module.isAllDayEvent());
 		var recurring = dhtml.getElementById("recurring").value;
 		var basedate = dhtml.getElementById("basedate").value;
 		if(recurring != 1 || basedate) {
@@ -916,9 +915,9 @@ function onAppointmentTabChange(newTab,oldTab)
 				if(organizerStore.emailaddress && organizerStore.emailaddress != webclient.username){
 					organizer = organizerStore.username;
 				}else{
-					var mucStore = parentWebclient.getMUCStore(module.storeid);
-					if(mucStore.emailaddress && mucStore.emailaddress != webclient.username){
-						organizer = mucStore.username;
+					var mucUsername = getMUCStoreUsername(parentWebclient, module.storeid);
+					if(mucUsername){
+						organizer = mucUsername;
 					}else{
 						organizer = webclient.username;
 					}
@@ -929,6 +928,7 @@ function onAppointmentTabChange(newTab,oldTab)
 			//update the meetingtime in freebusy tab
 			fb_module.setStartMeetingTime(module.getStartTime());
 			fb_module.setEndMeetingTime(module.getEndTime());
+			fb_module.setAllDayEvent(module.isAllDayEvent());
 
 			// Disable the picker when opening the whole serie of a recurrent item.
 			var recurring = dhtml.getElementById("recurring").value;
@@ -955,6 +955,8 @@ function onAppointmentTabChange(newTab,oldTab)
 		if(oldTab == "tracking") {
 			fb_module.setStartMeetingTime(module.getStartTime());
 			fb_module.setEndMeetingTime(module.getEndTime());
+			fb_module.setAllDayEvent(module.isAllDayEvent());
+
 			var recurring = dhtml.getElementById("recurring").value;
 			var basedate = dhtml.getElementById("basedate").value;
 			if(recurring != 1 || basedate) {
@@ -966,6 +968,7 @@ function onAppointmentTabChange(newTab,oldTab)
 		//update the appointment time in appointment tab
 		module.setStartTime(fb_module.getStartMeetingTime());
 		module.setEndTime(fb_module.getEndMeetingTime());
+		module.setAllDayEvent(fb_module.isAllDayEvent());
 	}
 	if(newTab == "appointment"){
 		if(fb_module){
@@ -1015,6 +1018,29 @@ function onAppointmentTabChange(newTab,oldTab)
 	}
 }
 
+/**
+ * Will loop through all the multiusercalendarmodules and try to find the a store that has been 
+ * opened by one of the modules that matches the supplied storeid argument. It will return the 
+ * username of the one that matches.
+ *
+ * @param Object webclient The webclient to retrieve the modules from
+ * @param string storeid the storeid
+ * @return string username Username
+ */
+function getMUCStoreUsername(webclient, storeid){
+	var mucModules = webclient.getModulesByName('multiusercalendarmodule');
+	for(var i=0;i<mucModules.length;i++){
+		var groups = mucModules[i].groups;
+		for(var j=0;j<groups.length;j++){
+			var groupStoreId = groups[i].storeid;
+			if(groupStoreId == storeid){
+				return groups[i].username;
+			}
+		}
+	}
+	return false;
+}
+
 function showRecurrence()
 {
 	var recurring = dhtml.getElementById("recurring").value;
