@@ -95,7 +95,7 @@ function attachItemAddColumns(moduleObject, properties) {
 		var doNotAddProperty = false;
 
 		// first remove previous columns before adding new one
-		moduleObject.tableWidget.columns = new Array();;
+		moduleObject.tableWidget.columns = new Array();
 
 		for(var index = 0; index < properties.length; index++) {
 			var property = properties[index];
@@ -457,7 +457,7 @@ function attachItemRenderRowColumnData(moduleObject, itemData, properties) {
 				} else if(xmlNode && xmlNode.getAttribute("type") == "timestamp_date") {
 					value = strftime_gmt(_("%a %x %X"), xmlValue);
 				} else if(typeof xmlValue != null) {
-					value = xmlValue;
+					value = xmlValue.htmlEntities();
 				} else {
 					value = NBSP;
 				}
