@@ -75,14 +75,18 @@ function setCursorPosition(message_action) {
 				// FCKEditor is installed
 				if(typeof(FCKeditorAPI) != "undefined" && (fckEditor = FCKeditorAPI.GetInstance("html_body"))) {
 					if(cursorPos == "start") {
-						fckEditor.Focus();
+						if(message_action != "forward")
+							fckEditor.Focus();
 					} else {
-						if(fckEditor.EditorWindow.document){
+						if(fckEditor.EditorWindow.document && module.signature != ""){
 							// Create a element and place at the end of editor
 							var pEle = dhtml.addElement(fckEditor.EditorWindow.document.body, 'p', false, false, null, fckEditor.EditorWindow);
-							// Select newly inserted element.
-							fckEditor.Selection.SelectNode(pEle);
-							fckEditor.Selection.Save();
+							if(message_action != "forward")
+							{
+								// Select newly inserted element.
+								fckEditor.Selection.SelectNode(pEle);
+								fckEditor.Selection.Save();
+							}
 							// Update scrolling
 							fckEditor.EditingArea.Document.documentElement.scrollTop = fckEditor.EditingArea.Document.body.lastChild.offsetTop;
 							fckEditor.EditingArea.Document.documentElement.scrollLeft = 0;
@@ -92,7 +96,8 @@ function setCursorPosition(message_action) {
 							signatureElement.innerHTML = module.signature;
 
 							// Now we can put focus on editor.
-							fckEditor.Focus();
+							if(message_action != "forward")
+								fckEditor.Focus();
 						}else{
 							break;
 						}
@@ -141,7 +146,7 @@ function isMessageBodyEmpty()
  */
 function checkNamesCallBackCreateMail(resolveObj)
 {
-	checkNamesCallBack(resolveObj);
+	checkNamesCallBack(resolveObj, true);
 
 	//Send mail
 	if(window.resolveForSendingMessage === true){
