@@ -354,6 +354,10 @@ function eventRecurrenceAllDayEvent(moduleObject, element, event)
 	if (element.checked){
 		moduleObject.appo_start.setValue(0);
 		moduleObject.appo_end.setValue(0);
+	}else{
+		var startValue =  moduleObject.appo_start.getValue();
+		var newEndValue = startValue + (HALF_HOUR/1000);
+		moduleObject.appo_end.setValue(newEndValue);
 	}
 }
 
@@ -370,6 +374,9 @@ function eventApptStartTimePickerChange(startTpObj, oldStartValue, startTpObjDay
 
 	if (newEndValue != oldEndValue)
 		window.appo_end.setValue(newEndValue);
+
+	if(dhtml.getElementById("allday_event").checked)
+		dhtml.getElementById("allday_event").checked = false;
 }
 
 function eventApptEndTimePickerChange(endTpObj, oldEndValue, endTpObjDayValue)
@@ -383,6 +390,9 @@ function eventApptEndTimePickerChange(endTpObj, oldEndValue, endTpObjDayValue)
 
 	if (oldStartValue >= newEndValue && duration >= 0)
 		window.appo_start.setValue(newEndValue - (HALF_HOUR/1000));
+
+	if(dhtml.getElementById("allday_event").checked)
+		dhtml.getElementById("allday_event").checked = false;
 }
 
 /**
