@@ -224,7 +224,7 @@ function initRestoreItems(data, type){
 					break;
 				default:
 					if(typeof(itemData[colId])!="undefined"){
-						value = itemData[colId];
+						value = String(itemData[colId]).htmlEntities();
 					}else{
 						value = "&nbsp;";
 					}
