@@ -174,32 +174,49 @@ function showAction(action, state)
         dhtml.getElementById("action_copy_folder").storeentryid = action.storeentryid.value;
         dhtml.getElementById("action_copy_folder").innerHTML = action.foldername.value;
     } else if(action.action.value == "OP_FORWARD") {
-        dhtml.getElementById("action_forward").checked = true;
-        
-        var smtpaddress = "";
-        var emailaddress = "";
+		var smtpaddress = "";
+		var emailaddress = "";
 		var addrType = "";
-        
-        for(var i=0;i<action.adrlist.address.property.length;i++) {
-            if(action.adrlist.address.property[i].attributes.proptag == "PR_SMTP_ADDRESS") {
-                smtpaddress = action.adrlist.address.property[i].value;
-            }
-            if(action.adrlist.address.property[i].attributes.proptag == "PR_EMAIL_ADDRESS") {
-                emailaddress = action.adrlist.address.property[i].value;
-            }
-            if(action.adrlist.address.property[i].attributes.proptag == "PR_ADDRTYPE") {
-                addrType = action.adrlist.address.property[i].value;
-            }
-        }
+		var displayName = "";
+		var objectType = MAPI_MAILUSER;
+		
+		for(var i=0;i<action.adrlist.address.property.length;i++) {
+			if(!action.adrlist.address.property[i].attributes) {
+				continue;
+			}
 
-		if (addrType=="ZARAFA"){
-	        dhtml.getElementById("action_forward_address").value = smtpaddress;
-		}else if(addrType=="SMTP"){
-	        dhtml.getElementById("action_forward_address").value = emailaddress;
-		}else{
-			return;
+			if(action.adrlist.address.property[i].attributes.proptag == "PR_SMTP_ADDRESS") {
+				smtpaddress = action.adrlist.address.property[i].value;
+			}
+			if(action.adrlist.address.property[i].attributes.proptag == "PR_EMAIL_ADDRESS") {
+				emailaddress = action.adrlist.address.property[i].value;
+			}
+			if(action.adrlist.address.property[i].attributes.proptag == "PR_ADDRTYPE") {
+				addrType = action.adrlist.address.property[i].value;
+			}
+			if(action.adrlist.address.property[i].attributes.proptag == "PR_OBJECT_TYPE") {
+				objectType = action.adrlist.address.property[i].value;
+			}
+			if(action.adrlist.address.property[i].attributes.proptag == "PR_DISPLAY_NAME") {
+				displayName = action.adrlist.address.property[i].value;
+			}
 		}
-    }
+
+		if(smtpaddress && displayName) {
+			emailaddress = nameAndEmailToString(displayName, smtpaddress, objectType);
+		}
+
+		if(action.flavor.value == "0"){
+			dhtml.getElementById("action_forward").checked = true;
+			dhtml.getElementById("action_forward_address").value = emailaddress;
+		}else if(action.flavor.value == "FWD_AS_ATTACHMENT"){
+			dhtml.getElementById("action_forward_attach").checked = true;
+			dhtml.getElementById("action_forward_attach_address").value = emailaddress;
+		}else if(action.flavor.value == "FWD_PRESERVE_SENDER | FWD_DO_NOT_MUNGE_MSG"){
+			dhtml.getElementById("action_redirect").checked = true;
+			dhtml.getElementById("action_redirect_address").value = emailaddress;
+		}
+	}
 }
 
 // Called when user presses 'ok'. Returns true if window should close, false otherwise
@@ -211,10 +228,19 @@ function submitRule()
     var action_copy = dhtml.getElementById("action_copy").checked;
     var action_delete = dhtml.getElementById("action_delete").checked;
     var action_forward = dhtml.getElementById("action_forward").checked;
+    var action_forward_attach = dhtml.getElementById("action_forward_attach").checked;
+    var action_redirect = dhtml.getElementById("action_redirect").checked;
     
     var action_move_folder = dhtml.getElementById("action_move_folder");
     var action_copy_folder = dhtml.getElementById("action_copy_folder");
-    var action_forward_address = dhtml.getElementById("action_forward_address").value;
+
+	if(action_forward){
+		var action_address = dhtml.getElementById("action_forward_address").value;
+	}else if(action_forward_attach){
+		var action_address = dhtml.getElementById("action_forward_attach_address").value;
+	}else if(action_redirect){
+	    var action_address = dhtml.getElementById("action_redirect_address").value;
+	}
     
     var name = dhtml.getElementById("name").value;
     var sequence = dhtml.getElementById("sequence").value;
@@ -226,7 +252,7 @@ function submitRule()
     var cond_sent_to = dhtml.getElementById("cond_sent_to").value;
     var cond_sent_to_me = dhtml.getElementById("cond_sent_to_me").checked;
     
-    if(!action_move && !action_copy && !action_delete && !action_forward) {
+    if(!action_move && !action_copy && !action_delete && !action_forward && !action_forward_attach && !action_redirect) {
         alert(_("Please select an appropriate action for this rule"));
         return false;
     }
@@ -241,16 +267,36 @@ function submitRule()
         return false;
     }
     
-    if(action_forward && !action_forward_address) {
-        alert(_("Please specify a forwarding address"));
-        return false;
-    }
-    if(action_forward && !parseEmailAddress(action_forward_address)) {
-        alert(_("Please specify a forwarding address")+"\n"+_("Please input a valid email address!"));
-
-        return false;
+	// check for validity of forwarding email address
+	if(action_forward && !action_address) {
+		alert(_("Please specify a forwarding address"));
+		return false;
 	}
-    
+	if(action_forward && !parseEmailAddress(action_address)) {
+		alert(_("Please specify a forwarding address")+"\n"+_("Please input a valid email address!"));
+		return false;
+	}
+
+	// check for validity of forwarding as attachment email address
+	if(action_forward_attach && !action_address) {
+		alert(_("Please specify a forwarding as attachment address"));
+		return false;
+	}
+	if(action_forward_attach && !parseEmailAddress(action_address)) {
+		alert(_("Please specify a forwarding as attachment address")+"\n"+_("Please input a valid email address!"));
+		return false;
+	}
+
+	// check for validity of redirecting email address
+	if(action_redirect && !action_address) {
+		alert(_("Please specify a redirecting address"));
+		return false;
+	}
+	if(action_redirect && !parseEmailAddress(action_address)) {
+		alert(_("Please specify a redirecting address")+"\n"+_("Please input a valid email address!"));
+		return false;
+	}
+
     // Create name if none given
     if(!name) {
         var conditions = new Array();
@@ -378,13 +424,17 @@ function getConditions()
     }
     
     if(cond_sent_to.value) {
-        var parsed = parseEmailAddress(cond_sent_to.value);
-        var addrtype = cond_sent_to.addrtype ? cond_sent_to.addrtype : "SMTP";
-        var emailaddr = cond_sent_to.emailaddress ? cond_sent_to.emailaddress : parsed.emailaddress;
-        var name = cond_sent_to.displayname ? cond_sent_to.displayname : (parsed.displayname ? parsed.displayname : parsed.emailaddress);
-        var entryid = cond_sent_to.entryid ? cond_sent_to.entryid : createOneOff(name, addrtype, emailaddr);
-        var searchkey = cond_sent_to.searchkey ? cond_sent_to.searchkey : createSearchKey(addrtype, emailaddr);
-        
+		var parsed = parseEmailAddress(cond_sent_to.value);
+		var addrtype = cond_sent_to.addrtype ? cond_sent_to.addrtype : "SMTP";
+		var emailaddr = '';
+		if(cond_sent_to.emailaddress) {
+			emailaddr = cond_sent_to.emailaddress;
+		}
+		var smtpaddr = cond_sent_to.smtpaddr ? cond_sent_to.smtpaddr : parsed.emailaddress;
+		var name = cond_sent_to.displayname ? cond_sent_to.displayname : (parsed.displayname ? parsed.displayname : parsed.emailaddress);
+		var entryid = cond_sent_to.entryid ? cond_sent_to.entryid : createOneOff(name, addrtype, smtpaddr);
+		var searchkey = cond_sent_to.searchkey ? cond_sent_to.searchkey : createSearchKey(addrtype, smtpaddr);
+
         condition = new Object;
         condition.restype = new Object;
         condition.restype.value = "RES_SUBRESTRICTION";
@@ -496,12 +546,21 @@ function getAction()
     var action_move = dhtml.getElementById("action_move").checked;
     var action_copy = dhtml.getElementById("action_copy").checked;
     var action_delete = dhtml.getElementById("action_delete").checked;
+    var action_redirect = dhtml.getElementById("action_redirect").checked;
     var action_forward = dhtml.getElementById("action_forward").checked;
+    var action_forward_attach = dhtml.getElementById("action_forward_attach").checked;
     
     var action_move_folder = dhtml.getElementById("action_move_folder");
     var action_copy_folder = dhtml.getElementById("action_copy_folder");
-    var action_forward_address = dhtml.getElementById("action_forward_address");
-
+	
+	if(action_redirect){
+		var action_address = dhtml.getElementById("action_redirect_address");
+	}else if(action_forward){
+		var action_address = dhtml.getElementById("action_forward_address");
+	}else if(action_forward_attach){
+		var action_address = dhtml.getElementById("action_forward_attach_address");
+	}
+    
     var action = new Object;
     
     if(action_move) {
@@ -531,19 +590,31 @@ function getAction()
         action.storeentryid.value = parentwindow.module.storeid;
         action.foldername = new Object;
         action.foldername.value = "DELETE";
-    } else if(action_forward) {
-        var parsed = parseEmailAddress(action_forward_address.value);
-        var addrtype = action_forward_address.addrtype ? action_forward_address.addrtype : "SMTP";
-        var emailaddr = action_forward_address.emailaddress ? action_forward_address.emailaddress : parsed.emailaddress;
-        var smtpaddr = action_forward_address.smtpaddr ? action_forward_address.smtpaddr : parsed.smtpaddress;
-        var name = action_forward_address.displayname ? action_forward_address.displayname : (parsed.displayname ? parsed.displayname : parsed.emailaddress);
-        var entryid = action_forward_address.entryid ? action_forward_address.entryid : createOneOff(name, addrtype, emailaddr);
-		var searchkey = action_forward_address.searchkey ? action_forward_address.searchkey : createSearchKey(addrtype, emailaddr);
+    } else if(action_forward || action_redirect || action_forward_attach) {
+
+        var parsed = parseEmailAddress(action_address.value);
+        var addrtype = action_address.addrtype ? action_address.addrtype : "SMTP";
+		var emailaddr = '';
+		if(action_address.emailaddress) {
+			emailaddr = action_address.emailaddress;
+		}
+        var smtpaddr = action_address.smtpaddr ? action_address.smtpaddr : parsed.emailaddress;
+        var name = action_address.displayname ? action_address.displayname : (parsed.displayname ? parsed.displayname : parsed.emailaddress);
+        var entryid = action_address.entryid ? action_address.entryid : createOneOff(name, addrtype, smtpaddr);
+		var searchkey = action_address.searchkey ? action_address.searchkey : createSearchKey(addrtype, smtpaddr);
 
         action.action = new Object;
         action.action.value = "OP_FORWARD";
         action.flavor = new Object;
-        action.flavor.value = 3; // FWD_PRESERVE_SENDER | FWD_DO_NOT_MUNGE_MSG -> Redirect
+
+		if (action_forward){
+			action.flavor.value = "0"; 
+		} else if (action_forward_attach) {
+			action.flavor.value = "FWD_AS_ATTACHMENT";
+		} else if (action_redirect) {
+			action.flavor.value = "FWD_PRESERVE_SENDER | FWD_DO_NOT_MUNGE_MSG"; // Redirect
+		}
+
         action.adrlist = new Object;
         action.adrlist.address = new Object;
         action.adrlist.address.property = new Array();
@@ -592,11 +663,19 @@ function getAction()
         property.value = 6;
         action.adrlist.address.property.push(property);
 
-        var property = new Object;
-        property.attributes = new Object;
-        property.attributes.proptag = "PR_EMAIL_ADDRESS";
-        property.value = emailaddr;
-        action.adrlist.address.property.push(property);
+		if(emailaddr) {
+			var property = new Object;
+			property.attributes = new Object;
+			property.attributes.proptag = "PR_EMAIL_ADDRESS";
+			property.value = emailaddr;
+			action.adrlist.address.property.push(property);
+		}
+
+		var property = new Object;
+		property.attributes = new Object;
+		property.attributes.proptag = "PR_SMTP_ADDRESS";
+		property.value = smtpaddr;
+		action.adrlist.address.property.push(property);
 
 		if (addrtype == "SMTP"){
 	        var property = new Object;
@@ -617,12 +696,6 @@ function getAction()
 		    property.attributes.type = "binary";
 			property.value = searchkey;
 	        action.adrlist.address.property.push(property);
-		}else{
-	        var property = new Object;
-	        property.attributes = new Object;
-	        property.attributes.proptag = "PR_SMTP_ADDRESS";
-	        property.value = smtpaddr;
-	        action.adrlist.address.property.push(property);
 		}
     }
     
