@@ -107,6 +107,7 @@ function initTask()
 		if(text_totalwork) {
 			totalwork.value /= 60;
 			text_totalwork.value = totalwork.value + " " + ((totalwork.value==1) ? _("hour") : _("hours"));
+			dhtml.executeEvent(text_totalwork, "change");
 		}
 	}
 	
@@ -272,8 +273,8 @@ function onChangeStatus()
 			//check reminder and turn it off
 			setReminderOnComplete();
 			showHideRecurrenceMenu(true);
-		} else {
-			dhtml.getElementById("text_percent_complete").value = (dhtml.getElementById("percent_complete").value * 100) + "%";
+		}else {
+			dhtml.getElementById("text_percent_complete").value = "0%";
 			//check reminder and turn it on
 			setReminderOnComplete(true);
 			showHideRecurrenceMenu(false);
@@ -812,3 +813,25 @@ function copyExtraInfo()
 	disabledExtraInfo.innerHTML = dhtml.getElementById("extrainfo").innerHTML;
 	disabledExtraInfo.innerHTML += dhtml.getElementById("recurtext").innerHTML;
 }
+
+
+function eventTaskWorkChange(moduleObject, element, event)
+{
+	var value = element.value;
+	var work = parseFloat(value);
+
+	if (value.indexOf(_("hour")) != -1 || value.indexOf(_("hours")) != -1 || value.indexOf("hour") != -1 || value.indexOf("hours") != -1) {
+		if (work >= 10) convertToDays();
+	} else if (value.indexOf(_("day")) != -1 || value.indexOf(_("days")) != -1 || value.indexOf("day") != -1 || value.indexOf("days") != -1) {
+		if (work/5 >= 1) convertToWeeks(work);
+	}
+
+	function convertToDays() {
+		if (work/8 >= 5) convertToWeeks(work/8);
+		else element.value = Math.round((work/8)*10)/10 +" "+ (work/8 == 1 ? _("day") : _("days"));
+	}
+
+	function convertToWeeks(days) {
+		element.value = Math.round((days/5)*10)/10 +" "+ (days/5 == 1 ? _("week") : _("weeks"));
+	}
+}
\ No newline at end of file
