@@ -50,7 +50,7 @@
 
 ?>
 <?php
-	
+	$user = htmlentities($_GET["user"]);
 	header("Content-type: text/html; charset=utf-8");
 ?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -61,7 +61,11 @@
 		<link rel="shortcut icon" href="client/layout/img/favicon.ico" type="image/x-icon">	
 		<script type="text/javascript">
 			window.onload = function(){
-				document.getElementById("username").focus();
+				if (document.getElementById("username").value == ""){
+					document.getElementById("username").focus();
+				}else if (document.getElementById("password").value == ""){
+					document.getElementById("password").focus();
+				}
 			}
 		</script>
 	</head>
@@ -69,11 +73,11 @@
 		<table id="layout">
 			<tr><td>
 				<div id="login_main">
-					<form action="index.php?logon" method="post">
+					<form action="index.php?logon<?=($user)?'&user='.$user:''?>" method="post">
 					<!-- Store action attributes to hidden variable to pass it to index page -->
 					<?php	if($_POST && $_POST["action_url"] != "") {	?>
 								<!-- if login has failed then action attributes will be in POST variable -->
-								<input type="hidden" name="action_url" value="<?= $_POST["action_url"] ?>"></input>
+								<input type="hidden" name="action_url" value="<?= htmlspecialchars($_POST["action_url"]) ?>"></input>
 					<?php	} else {	?>
 								<!-- or else in the URL -->
 								<input type="hidden" name="action_url" value="<?= stristr($_SERVER["REQUEST_URI"], "?action=") ?>"></input>
@@ -105,7 +109,7 @@
 							<table id="form_fields">
 								<tr>
 									<th><label for="username"><?=_("Name")?>:</label></th>
-									<td><input type="text" name="username" id="username" class="inputelement"></td>
+									<td><input type="text" name="username" id="username" class="inputelement" <?=($user)?'value="'.$user.'"':''?>></td>
 								</tr>
 								<tr>
 									<th><label for="password"><?=_("Password")?>:</label></th>
