@@ -76,10 +76,13 @@ addressbooklistmodule.prototype.init = function(id, element, title, data)
 
 	var items = new Array();
 	if (data["showsendmail"] == "true") {
+		// If addressbook is opened from the main toolbar then show "Email Message" option as contextmenu item.
 		items.push(webclient.menu.createMenuItem("createmail", _("Email Message"), false, eventABSendMailTo));
 	} else {
+		// If addressbook is opened from the other dialoge then show "Select" option as contextmenu item.
 		items.push(webclient.menu.createMenuItem("select", _("Select"), false, eventListContextMenuOpenMessage));
 	}
+	items.push(webclient.menu.createMenuItem("details", _("Properties"), false, eventListContextMenuOpenProperties));
 	this.contextmenu = items;
 }
 
@@ -257,6 +260,75 @@ addressbooklistmodule.prototype.updateHierarchy = function(action)
 	}
 }
 
-// Override listmodule's onOpenItem to do nothing; we don't want to open the item when it is clicked
-addressbooklistmodule.prototype.onOpenItem = function() {
+/** 
+ * Opens the entry based on the supplied entryid. The messageClass is only needed when calling the 
+ * openDetails method.
+ * @param entryid String Entryid of the entry that has to be opened
+ * @param messageClass String Message class of the entry based on the CSS classname 
+ */
+addressbooklistmodule.prototype.onOpenItem = function(entryid, messageClass) {
+	// Only open the details dialog when this has been set for this dialog
+	if(this.detailsonopen){
+		this.openDetails(entryid, messageClass);
+		return false;
+	}
 }
+
+/** 
+ * Opens the entry based on the supplied entryid. The messageClass is only needed when the object 
+ * type of the entry is a MAPI_MESSAGE. In that case the superlclass' onOpenItem is called to handle
+ * according to the default behavior. The Message class is usually based on the CSS class name and
+ * will be used to determine the type of dialog that has to be opened.
+ * @param entryid String Entryid of the entry that has to be opened
+ * @param messageClass String Message class of the entry based on the CSS classname 
+ */
+addressbooklistmodule.prototype.openDetails = function(entryid, messageClass) {
+	var objecttype = parseInt(this.itemProps[ entryid ].objecttype, 10);
+
+	switch(objecttype){
+		case MAPI_MAILUSER:
+			var uri = DIALOG_URL+"task=gab_detail_mailuser_standard&storeid=" + this.storeid + "&entryid=" + entryid;
+			webclient.openWindow(this, "gab_detail", uri, FIXEDSETTINGS.ABITEM_DIALOG_MAILUSER_WIDTH, FIXEDSETTINGS.ABITEM_DIALOG_MAILUSER_HEIGHT);
+			break;
+		case MAPI_DISTLIST:
+		case MAPI_ABCONT:
+			var uri = DIALOG_URL+"task=gab_detail_distlist_standard&storeid=" + this.storeid + "&entryid=" + entryid;
+			webclient.openWindow(this, "gab_detail", uri, FIXEDSETTINGS.ABITEM_DIALOG_DISTLIST_WIDTH, FIXEDSETTINGS.ABITEM_DIALOG_DISTLIST_HEIGHT);
+			break;
+		case MAPI_MESSAGE:
+			// If it is a normal item open the item using the superclass' method
+			addressbooklistmodule.superclass.onOpenItem.apply(this, arguments);
+			break;
+	}
+}
+
+/**
+ * Called when the user wants to open the properties dialog of an entry in the GAB.
+ * @param moduleObject Object Module Object
+ * @param element HTMLElement Clicked element
+ * @param event Object Event object
+ */
+function eventListContextMenuOpenProperties(moduleObject, element, event)
+{
+	// Hide the menu
+	element.parentNode.style.display = "none";
+
+	// Get the id of the element the menu is opened for. This is not necessarily the selected item
+	var elementIdParentContextMenu = element.parentNode.elementid;
+
+	// Get the message_class through the CSS classname
+	// TODO refactor this code, as this is used everywhere in the WA.
+	var parentElement = dhtml.getElementById(elementIdParentContextMenu);
+	var messageClass = false;
+	if(parentElement){
+		var classNames = parentElement.className.split(" ");
+		for(var index in classNames){
+			if(classNames[index].indexOf("ipm_") >= 0 && messageClass==false) {
+				messageClass = classNames[index].substring(classNames[index].indexOf("_") + 1);
+			}
+		}
+	}
+
+	// Open the details of the item
+	moduleObject.openDetails(moduleObject.entryids[elementIdParentContextMenu], messageClass);
+}
\ No newline at end of file
