@@ -117,6 +117,23 @@ appointmentitemmodule.prototype.setEndTime = function(unixtime)
 	dhtml.getElementById("commonend").setAttribute("unixtime",unixtime);
 	appoint_dtp.setEndValue(unixtime);
 }
+
+/**
+ * Function will create and allday event and show/hide time element of date pickers
+ * in the appointment tab
+ * @param boolean allday event flag
+ */
+appointmentitemmodule.prototype.setAllDayEvent = function(allDayEventFlag)
+{
+	dhtml.getElementById("checkbox_alldayevent").checked = allDayEventFlag;
+	if(allDayEventFlag){
+		appoint_dtp.startPicker.timeElement.hide();
+		appoint_dtp.endPicker.timeElement.hide();
+	}else{
+		appoint_dtp.startPicker.timeElement.show();
+		appoint_dtp.endPicker.timeElement.show();
+	}
+}
 /**
  * Function will set the location of the meeting in the appointment
  * @param string resource
@@ -146,6 +163,14 @@ appointmentitemmodule.prototype.getEndTime = function()
 	return appoint_dtp.getEndValue();
 }
 
+/**
+ * Function which will return the all day status of an appointment
+ */
+appointmentitemmodule.prototype.isAllDayEvent = function()
+{
+	return dhtml.getElementById("checkbox_alldayevent").checked;
+}
+
 /**
  * Function will return the selected users
  * @return Array[]->entryid
@@ -312,6 +337,14 @@ appointmentitemmodule.prototype.setRecurrence = function(recurrence)
 			dhtml.getElementById("endocc").value = 1440;
 			dhtml.getElementById("startocc").value = 0;
 			dhtml.getElementById("duration").value = 1440;
+		}else if(this.isAllDayEvent()){
+			/**
+			 * this check is to unset allday event in appointment dialog, in case when the appointment
+			 * dialog has all day event check but in recurring dialog user has unchecks 
+			 * all day checkbox, thus we would like to propogate this change to appointment dialog
+			 */
+			dhtml.setValue(dhtml.getElementById("checkbox_alldayevent"), false);
+			onChangeAllDayEvent();
 		}
 	} else {
 		dhtml.getElementById('recurring').value = 0;
@@ -457,6 +490,9 @@ appointmentitemmodule.prototype.execute = function (type, action)
 		case "saved":
 			this.messageSaved(action);
 			break;
+		case "deleted":
+			this.messageDeleted(action);
+			break;
 		case "error":
 			this.handleError(action);
 			break;
@@ -546,7 +582,7 @@ appointmentitemmodule.prototype.messageSaved = function(action)
 					break;
 				}
 			}
-			if(resourcesPlanned){
+			if(resourcesPlanned && Number(dhtml.getXMLValue(action, "direct_booking_enabled"))){
 				alert(_("Resources have been planned."));
 			}
 		}
@@ -596,4 +632,13 @@ appointmentitemmodule.prototype.messageSaved = function(action)
 
 	module.saving = false;
 	module.savingMeetingRequest = false;
+}
+
+/**
+ * Called when a deleted action was successful. Will close the dialog.
+ * @param {XMLElement} action Response from server
+ */
+appointmentitemmodule.prototype.messageDeleted = function(action)
+{
+	window.close();
 }
\ No newline at end of file
