@@ -234,6 +234,21 @@ appointmentlistmodule.prototype.setDays = function(timestamp)
 	}
 }
 
+appointmentlistmodule.prototype.messageList = function(action)
+{
+	if (this.startdate && this.duedate) {
+		var restriction = action.getElementsByTagName("restriction")[0];
+		restriction = restriction ? dom2array(restriction) : false;
+
+		// Check if incoming records are for selected range view
+		if ((this.startdate/1000 == restriction.startdate) && (this.duedate/1000 == restriction.duedate))
+			appointmentlistmodule.superclass.messageList.call(this, action);
+	} else {
+		// listview is selected
+		appointmentlistmodule.superclass.messageList.call(this, action);
+	}
+}
+
 /**
  * Function which sends a request to the server, with the action "list".
  * @param boolean useTimeOut use a time out for the request (@TODO check this parameter is not used anymore)
@@ -375,7 +390,7 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 		 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
 		 * so if request is not sent to recipients then dont ask to update them while saving MR.
 		 */
-		if(endtime.getTime() > (new Date().getTime()) && !(selectedElement.requestsent && selectedElement.requestsent != "1")) {
+		if(endtime.getTime() > (new Date().getTime()) && selectedElement.requestsent && selectedElement.requestsent == "1") {
 			if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
 				send = confirm(_("Would you like to send an update to the attendees regarding cancellation of this meeting?"));
 				//if user does not want to cancel/delete the meeting,we want like to ignore this action
@@ -420,7 +435,7 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 		 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
 		 * so if request is not sent to recipients then dont ask to update them while saving MR.
 		 */
-		if (endtime.getTime() > (new Date().getTime()) && !(selectedElement.requestsent && selectedElement.requestsent != "1")) {
+		if (endtime.getTime() > (new Date().getTime()) && selectedElement.requestsent && selectedElement.requestsent == "1") {
 			// if recurrence is later then send confirmation message for cancellation message.
 			if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
 				send = confirm(_("Would you like to send an update to the attendees regarding cancellation of this meeting?"));
@@ -474,7 +489,8 @@ appointmentlistmodule.prototype.deleteAppointments = function(messages, promptoc
 	var classNames = itemEl.className.split(" ");
 	var entryid = this.entryids[itemEl.id];
 
-	var basedate = itemEl.attributes["basedate"] ? itemEl.attributes["basedate"].value : false;
+	//basedate for normal meetings is set as '0' i.e basedate doesn't exist, typecast it to integer so that later is doesn't break any IF statement
+	var basedate = itemEl.attributes["basedate"] ? parseInt(itemEl.attributes["basedate"].value, 10) : false;
 	var meeting = 0;
 	var send = false;
 	var deleteMessage = true;
@@ -500,7 +516,7 @@ appointmentlistmodule.prototype.deleteAppointments = function(messages, promptoc
 			 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
 			 * so if request is not sent to recipients then dont ask to update them while saving MR.
 			 */
-			if (MRResponseStatusOrganizer == olResponseOrganized && !(itemEl.requestsent && itemEl.requestsent != "1")) {
+			if (MRResponseStatusOrganizer == olResponseOrganized && itemEl.requestsent && itemEl.requestsent == "1") {
 				// don't ask for meeting requests which are occuring in past
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 				deleteMessage = false;
@@ -535,6 +551,13 @@ appointmentlistmodule.prototype.handleActionFailure = function(action)
 			if(errorMessageString != false)
 				alert(errorMessageString);
 			break;
+		case "remindertime":
+			var errorMessageString = dhtml.getXMLValue(action, "error_message");
+			if(errorMessageString){
+				alert(errorMessageString);
+				this.list();
+			}
+			break;
 		case "bookresource":
 			var name = (dhtml.getXMLValue(action, "displayname"))?dhtml.getXMLValue(action, "displayname"):'(Unknown)';
 			/**
@@ -678,7 +701,7 @@ function eventAppointmentListKeyCtrlChangeView(moduleObject, element, event)
 function confirmAppointMoved(moduleObject, currentDay, targetDay)
 {
 	if(currentDay != targetDay){
-		if(!confirm(_("You changed the date of this occurence. If you want to change the date of all occurences, you must first open the appointment series. Do you want to change only this occurence?"))){
+		if(!confirm(_("You changed the date of this occurrence. If you want to change the date of all occurrences, you must first open the appointment series. Do you want to change only this occurrence?"))){
 			/**
 			 * Here position of the occurrence is changed,
 			 * so replace it with original call list function of module.
