@@ -195,30 +195,6 @@ contactitemmodule.prototype.parseDetailedInfo = function (data, type, returnResu
 				this.result = this.parsingObject.parseDetailedPhoneNumberInfo(data);
 			}
 			break;
-		case "address":
-			// parse address and return an object with all fields
-			if(data.length >= 1) {
-				this.result = this.parsingObject.parseDetailedAddressInfo(data);
-			}
-
-			// check that dialog should be displayed when field is incomplete or unclear
-			var settingValue = webclient.settings.get("addressbook/show_detailed_address_dialog", "true");
-			// convert true/false string type values to boolean type
-			settingValue = (settingValue == "true") ? true : false;
-			this.result["setting"] = settingValue;
-
-			if(returnResult == false && this.parsingObject.incompleteInfo == true) {
-				if(settingValue) {
-					dhtml.executeEvent(dhtml.getElementById("address_button"), "click");
-				}
-
-				// we don't need to reset this flag as contactparsingobject will reset it
-				this.parsingObject.incompleteInfo = false;
-			}
-
-			// store different field values to appropriate hidden variables
-			this.storeDetailedInfo(this.result, type, false);
-			break;
 	}
 
 	if(typeof returnResult != "undefined" && returnResult == true) {
@@ -261,6 +237,7 @@ contactitemmodule.prototype.storeDetailedInfo = function (data, type, show) {
 		case "phone_number":
 			// set value for phone number input box
 			dhtml.getElementById(this.selectedPhoneInputID).value = this.parsingObject.combinePhoneNumberInfo(data);
+			updatePhoneNumberFields();
 			break;
 		case "address":
 			// check which address is selected
@@ -282,14 +259,8 @@ contactitemmodule.prototype.storeDetailedInfo = function (data, type, show) {
 			dhtml.getElementById(address_prefix + "_address_postal_code").value = data["zip"];
 			dhtml.getElementById(address_prefix + "_address_country").value = data["country"];
 
-			if(typeof show != "undefined" && show == true) {
-				var address = this.parsingObject.combineAddressInfo(data);
-
-				dhtml.getElementById(address_prefix + "_address").value = address;
-
-				// set value for address textarea
-				dhtml.getElementById("address").value = address;
-			}
+			var address = this.parsingObject.combineAddressInfo(data);
+			dhtml.getElementById(address_prefix + "_address").value = address;
 
 			// convert true/false boolean type values to string type to store it in settings
 			webclient.settings.set("addressbook/show_detailed_address_dialog", (data["setting"] == true) ? "true" : "false");
@@ -321,4 +292,26 @@ contactitemmodule.prototype.setBodyFromItemData = function(action)
 	}else{
 		dhtml.getElementById("display_name").focus();
 	}
+}
+
+/**
+ * Function will resize the view (called when dialog is resized)
+ */
+contactitemmodule.prototype.resize = function()
+{
+	var html_body = dhtml.getElementById("html_body");
+	if(html_body) {
+		var height = html_body.clientHeight;
+		var attachFieldContainer = dhtml.getElementById("attachfieldcontainer");
+
+		if(attachFieldContainer) {
+			height -= attachFieldContainer.offsetHeight;
+		}
+
+		if(height < 50) {
+			height = 50;
+		}
+
+		html_body.style.height = (height - 10) + "px";
+	}
 }
\ No newline at end of file
