@@ -241,10 +241,10 @@ contactlistmodule.prototype.convertSelectedContactItem = function(action)
 	//show an alert message for contacts which do not have e-mail address specified
 	if(emailStringEmpty){
 		if(message.length < 2){
-			if(!confirm(_("You must first entert valid e-mail address for this contacts before you can send a mail to it")))
+			if(!confirm(_("You must first enter a valid e-mail address for this contact before you can send a message to it.")))
 				return;
 		}else{
-			if(!confirm(_("Some of these contacts do not have e-mail addresses. You may need to add the e-mail address to send them a mail")))
+			if(!confirm(_("Some of these contacts do not have e-mail addresses specified. E-mail addresses are required for sending them e-mail.")))
 				return;
 		}
 	}
@@ -394,7 +394,7 @@ contactlistmodule.prototype.initSearchBar = function()
 	dhtml.addEvent(this, searchFilterInputBox, "selectstart", eventContactListSearchBarFilterMouseMove);
 	dhtml.addEvent(this, searchFilterInputBox, "focus", eventContactListSearchFilterFocus);
 	dhtml.addEvent(this, searchFilterInputBox, "blur", eventContactListSearchFilterFocus);
-	dhtml.addEvent(this, searchFilterTarget, "mousedown", function(){event.stopPropagation()});
+	dhtml.addEvent(this, searchFilterTarget, "mousedown", function(module,element,event){event.stopPropagation()});
 
 	// subfolder search
 	// Only show subfolders when store supports search folders
