@@ -117,6 +117,7 @@ createmailitemmodule.prototype.execute = function(type, action)
 			window.waitForSaveResponse = false;
 			break;
 		case "success":		// mail sent successfully
+			window.messageChanged = false;
 			window.close();
 			break;
 
@@ -519,7 +520,7 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept, a
 						if(key == "body"){
 							content = data[key].value;
 						}else{
-							replyinfo += "<strong>" + data[key].label + ":</strong>\t" + data[key].value + "<br />";
+							replyinfo += "<strong>" + data[key].label + ":</strong>\t" + data[key].value.htmlEntities() + "<br />";
 						}
 					}
 				} else {
