@@ -146,13 +146,18 @@ datepickerlistmodule.prototype.changeMonth = function(month, year, previous, del
 	data["year"] = year;
 	
 	if(this.timeoutid)
-    	clearTimeout(this.timeoutid)
+		clearTimeout(this.timeoutid)
 	
 	this.viewController.initView(this.id, "datepicker", this.contentElement, this.events, data);
-	if(!delay)
-    	this.list();
-    else
-        this.timeoutid = setTimeout('webclient.modules.webclient_' + this.id + '.list(); webclient.xmlrequest.sendRequest();', 500);
+	if(!delay) {
+		this.list();
+	} else {
+		var module = this;
+		this.timeoutid = setTimeout(function() {
+			module.list();
+			webclient.xmlrequest.sendRequest();
+		}, 500);
+	}
 }
 
 datepickerlistmodule.prototype.getRestrictionData = function()
