@@ -75,11 +75,16 @@ function freebusymodule(startTime)
 	else{
 		this.startViewDate = new Date();
 	}
-	this.endViewDate = new Date(this.startViewDate.getTime()+(ONE_DAY*this.numberOfDays));
+
+	// Start from this.daysBefore before today
 	this.startViewDate.setHours(0);
 	this.startViewDate.setMinutes(0);
 	this.startViewDate.setSeconds(0);
-	this.startViewDate = new Date(this.startViewDate.getTime()-ONE_DAY*this.daysBefore);
+	this.startViewDate.setDate(this.startViewDate.getDate()-this.daysBefore);
+
+	// End this.numberOfDays after startViewDate
+	this.endViewDate = new Date(this.startViewDate.getTime());
+	this.endViewDate.setDate(this.endViewDate.getDate()+this.numberOfDays);
 
 	// This flag is set when fb_module is initialized for the first time, so that we can keep the track
 	// of wheather we can change the resource recipient when we switch between view while create meetings
@@ -97,6 +102,24 @@ freebusymodule.prototype.dtpOnchange = function()
 	fb_module.updatePicker();
 }
 
+/**
+ * Event handler which is called when all day checkbox in schedule is change
+ */
+freebusymodule.prototype.onChangeAllDay = function(){
+	
+	var checkbox_alldayevent = dhtml.getElementById("checkbox_allday");
+	
+	if(checkbox_alldayevent.checked) {
+		this.dtp.startPicker.timeElement.hide();
+		this.dtp.endPicker.timeElement.hide();
+	}else {
+		this.dtp.startPicker.timeElement.show();
+		this.dtp.endPicker.timeElement.show();
+	}
+	
+	fb_module.updatePicker();
+}
+
 freebusymodule.prototype.init = function(moduleID, element)
 {
 	this.moduleID = moduleID;	
@@ -141,7 +164,8 @@ freebusymodule.prototype.initView = function(zoom,user,recips)
 
 	//make day headers
 	for(var i=0;i<this.numberOfDays;i++){
-		curViewDate = new Date(this.startViewDate.getTime()+(ONE_DAY*i));
+		curViewDate = new Date(this.startViewDate.getTime());
+		curViewDate.setDate(curViewDate.getDate()+i);
 		var textToDisplay = DAYS_SHORT[curViewDate.getDay()]+" "
 			+curViewDate.getDate()+" "
 			+MONTHS_SHORT[curViewDate.getMonth()]+" "
@@ -213,7 +237,7 @@ freebusymodule.prototype.initView = function(zoom,user,recips)
 		
 		this.createUsers(newUser);
 	}
-	
+
 	this.resize();
 	this.updatePicker();
 }
@@ -600,13 +624,33 @@ freebusymodule.prototype.updateBusyInfo = function(clientuser)
 		}
 		var newBusyElement = dhtml.addElement(screenIn, "div", className);
 		newBusyElement.setAttribute("clientuser",clientuser);
-		newBusyElement.style.left = (25*((startUnixTime-this.startViewDate.getTime()/1000)/(ONE_HOUR/1000)))/this.zoom+"px";
+		secondsToStart = this.getDSTCorrectedDiff(this.startViewDate, new Date(startUnixTime*1000));
+		secondsToEnd = this.getDSTCorrectedDiff(this.startViewDate, new Date(dueUnixTime*1000));
+		newBusyElement.style.left = (25*(secondsToStart/(ONE_HOUR/1000)))/this.zoom+"px";
 		newBusyElement.style.top = 31+(this.getPositionUserList(clientuser)*19)+3+"px";
-		newBusyElement.style.width = (25*((dueUnixTime-startUnixTime)/(ONE_HOUR/1000)))/this.zoom+"px";
+		newBusyElement.style.width = (25*((secondsToEnd-secondsToStart)/(ONE_HOUR/1000)))/this.zoom+"px";
 		this.busyElements[clientuser].push(newBusyElement);
 	}
 }
 
+/**
+ * Get the DST corrected difference between start and end in seconds
+ *
+ * This is used for displaying times with a constant scale (so the scale doesn't
+ * show any DST jumps). This function outputs the number of seconds that there would 
+ * be between start and end if there were no DST jumps at all.
+ * @param Date start The start date
+ * @param Date end The end date
+ * @return Number The number of seconds without DST jumps
+ */
+freebusymodule.prototype.getDSTCorrectedDiff = function(start, end)
+{
+	var actualSeconds = (end.getTime() - start.getTime())/1000;
+	var bias = end.getTimezoneOffset() * 60 - start.getTimezoneOffset() * 60;
+	
+	return actualSeconds - bias;
+}
+
 /**
  * Function will look for a posible meeting point
  */ 
@@ -753,13 +797,29 @@ freebusymodule.prototype.updatePicker = function()
 	var pickerLeft = dhtml.getElementById("picker_left","div",this.element);
 	var picker = dhtml.getElementById("picker","div",this.element);
 	var pickerRight = dhtml.getElementById("picker_right","div",this.element);
-
-	var startUnixTime = this.dtp.getStartValue(); 
-	var dueUnixTime = this.dtp.getEndValue();
-	var tmpWidth,tmpLeft;
 	
-	tmpLeft = (25*((startUnixTime-this.startViewDate.getTime()/1000)/(ONE_HOUR/1000)))/this.zoom;
-	tmpWidth = ((25*((dueUnixTime-startUnixTime)/(ONE_HOUR/1000)))/this.zoom);
+	var startUnixTime = this.dtp.getStartValue(); 
+
+	var checkbox_alldayevent = dhtml.getElementById("checkbox_allday");
+	//if appointment is an allday event then add one day in endtime 
+	if(checkbox_alldayevent.checked) {
+		var enddate = new Date(this.dtp.getEndValue()*1000);
+		enddate.addDays(1);
+		var dueUnixTime = enddate.getTime()/1000;
+	}else{
+		var dueUnixTime = this.dtp.getEndValue(); 
+	}
+
+	var tmpWidth,tmpLeft,tmpRight,secondsDiff;
+	
+	// Calculate the nubmer of pixels of the left edge from the start of the timeline
+	secondsDiff = this.getDSTCorrectedDiff(this.startViewDate, new Date(startUnixTime*1000) );
+	tmpLeft = (25*(( secondsDiff )/(ONE_HOUR/1000)))/this.zoom;
+
+	// Calculate the width by first calculating the number of pixels to the right edge from the start of the timeline
+	secondsDiff = this.getDSTCorrectedDiff(this.startViewDate, new Date(dueUnixTime*1000) );
+	tmpRight = (25*(( secondsDiff )/(ONE_HOUR/1000)))/this.zoom;
+	tmpWidth = tmpRight - tmpLeft;
 	
 	//start time out of view leftside
 	if(tmpLeft<0){
@@ -842,6 +902,22 @@ freebusymodule.prototype.setEndMeetingTime = function(unixtime)
 		this.dtp.setEndValue(unixtime);
 }
 
+/**
+ * Function to change the the allday event checkbox in schedule tab
+ * @param boolean allDayEvent Flag
+ */
+freebusymodule.prototype.setAllDayEvent = function(allDayEventFlag)
+{
+	if(allDayEventFlag){
+		this.dtp.startPicker.timeElement.hide();
+		this.dtp.endPicker.timeElement.hide();
+	}else{
+		this.dtp.startPicker.timeElement.show();
+		this.dtp.endPicker.timeElement.show();
+	}
+
+	dhtml.getElementById("checkbox_allday").checked = allDayEventFlag;
+}
 /**
  * User this function to get the StartMeetingTime
  * @return int unixtime
@@ -860,6 +936,14 @@ freebusymodule.prototype.getEndMeetingTime = function()
 	return this.dtp.getEndValue();
 }
 
+/**
+ * Function which will return the all day status of an appointment
+ */
+freebusymodule.prototype.isAllDayEvent = function()
+{
+	return dhtml.getElementById("checkbox_allday").checked;
+}
+
 /**
  * Use this function to get the resource
  * @return string location
@@ -974,8 +1058,15 @@ function eventFreebusyPickHour(moduleObject, element, event)
 		
 		fb_module.freezeScrollbar = true;
 		var duration = (fb_module.getEndMeetingTime() - fb_module.getStartMeetingTime());
+
+		var startTimeline = new Date(fb_module.startViewDate.getTime());
+		var hoursSinceStartTimeline = xrel/25 * fb_module.zoom;
+		// If hoursSinceStartTimeline is higher than 24 it will go to the next day(s)
+		startTimeline.setHours( Math.floor(hoursSinceStartTimeline) );
+		// Use modulo to get the remainder of the hour and multiply it by 60 to get the minutes
 		// clicktime is the exact moment of clicking
-		var clicktime = fb_module.startViewDate.getTime()/1000 + ((xrel/25) * 60 * 60 * fb_module.zoom);
+		var clicktime = startTimeline.setMinutes( (hoursSinceStartTimeline % 1) * 60 ) / 1000;
+
 		var start = Math.floor(clicktime/(30*60))*30*60;
 		fb_module.setStartMeetingTime(start);
 		fb_module.setEndMeetingTime(start + duration);
