@@ -328,6 +328,11 @@ hierarchyselectmodule.prototype.createHierarchyList = function(load)
 		if(this.selectedFolder){
 			var selectedNode = tree.getNode(this.selectedFolder);
 			if (selectedNode && selectedNode.attributes.storeid == store.id) {
+				// as public folders by default are not expanded in dialog window,so expand selected folder's root node 
+				// if the selected folders's store is public
+				if( store.type == "public")
+					tree["root"]["open"] = true;
+
 				var parentNode	= tree.getNode(selectedNode["parentid"]);
 				while((parentNode != false) && (parentNode["id"] != store.root["entryid"])){
 					parentNode["open"] =(parentNode["hasChildNodes"]=="1")? true: false;
@@ -577,6 +582,9 @@ function eventHierarchyCopyMoveSelectFolder(moduleObject, element, event)
 		
 		moduleObject.selectedFolder = element.parentNode.id;
 		moduleObject.selectedFolderStoreId = element.parentNode.storeid;
+		//trigger the internal event register on onchangefolder in hierarchy.
+		moduleObject.sendEvent("changefolder");
+
 		var folderName = element.getElementsByTagName("span")[0];
 		folderName.className = "folder_title_selected";
 	}
