@@ -389,7 +389,7 @@ ItemModule.prototype.addAttachments = function(attachmentsElement, attachments)
 					attachmentLink.setAttribute("attach_num", (attachment["attach_num"]||false));
 					attachmentLink.href = "#";
 					var name = attachment["name"] || _("Untitled Attachment");
-					attachmentLink.innerHTML = name + " (" + kb + ");";
+					dhtml.addTextNode(attachmentLink, name + " (" + kb + ");");
 					dhtml.addEvent(this, attachmentLink, "mousedown", eventAttachmentClick);
 
 					dhtml.addTextNode(attachmentsElement, NBSP);
@@ -509,7 +509,7 @@ ItemModule.prototype.setBody = function(message, isReply, isConcept, addAsText)
 			if(key == "body"){
 				content += data[key].value;
 			}else{
-				content += data[key].label + ":\t" + data[key].value + "\n";
+				content += data[key].label + ":\t" + data[key].value.htmlEntities() + "\n";
 			}
 		}
 		if(html_body)
@@ -594,7 +594,7 @@ ItemModule.prototype.createAppointmentTemplate= function(message, htmlFormat)
 						}
 						result["required_attendee"] = new Object;
 						result["required_attendee"].label = _("Required Attendee");
-						result["required_attendee"].value = this.generateRecipientStringFromXML(message, "to");
+						result["required_attendee"].value = this.generateRecipientStringFromXML(message, "to", false);
 
 					} else {
 						xmlValue = NBSP;
@@ -634,7 +634,10 @@ ItemModule.prototype.createAppointmentTemplate= function(message, htmlFormat)
 				case "duedate":
 					xmlValue = strftime(_("%a %x %X"), xmlValue);
 					break;
-			}			
+				case "body":
+					xmlValue = htmlFormat? xmlValue.htmlEntities() : xmlValue;
+					break;
+			}
 			// add data in result
 			result[tagName] = new Object;
 			result[tagName].label = properties[tagName];
@@ -663,6 +666,9 @@ ItemModule.prototype.createContactTemplate= function(message, htmlFormat)
 				case "wedding_anniversary":
 					xmlValue = strftime(_("%a %x %X"), xmlValue);
 					break;
+				case "body":
+					xmlValue = htmlFormat? xmlValue.htmlEntities() : xmlValue;
+					break;
 			}
 			// add data in result
 			result[tagName] = new Object;
@@ -686,8 +692,8 @@ ItemModule.prototype.createStickyNoteTemplate= function(message, htmlFormat)
 		// add data in result
 		result["body"] = new Object;
 		result["body"].label = _("Body");
-		result["body"].value = dhtml.getXMLValue(message, "body", "");
-	
+		result["body"].value = htmlFormat ? dhtml.getXMLValue(message, "body", "").htmlEntities() : dhtml.getXMLValue(message, "body", "");
+		
 	return result;
 }
 
@@ -738,6 +744,9 @@ ItemModule.prototype.createTaskTemplate= function(message, htmlFormat)
 				case "percent_complete":
 					xmlValue = xmlValue *100 +"%";
 					break;
+				case "body":
+					xmlValue = htmlFormat? xmlValue.htmlEntities() : xmlValue;
+					break;
 			}
 			// add data in result
 			result[tagName] = new Object;
@@ -767,7 +776,7 @@ ItemModule.prototype.createMailTemplate= function(message, htmlFormat)
 					xmlValue = strftime(_("%a %x %X"), xmlValue);
 					break;
 				case "sent_representing_email_address":
-					xmlValue = nameAndEmailToString(dhtml.getXMLValue(message, "sent_representing_name", ""), xmlValue, MAPI_MAILUSER , htmlFormat);;
+					xmlValue = nameAndEmailToString(dhtml.getXMLValue(message, "sent_representing_name", ""), xmlValue, MAPI_MAILUSER , false);
 					break;
 				case "attachment":
 					xmlValue = this.generateAttachmentStringFromXML(message);
@@ -817,21 +826,26 @@ ItemModule.prototype.createMailTemplate= function(message, htmlFormat)
 					xmlValue = content;
 					break;
 			}
-			var recipients = this.generateRecipientStringFromXML(message, false, htmlFormat);
-			if (recipients){
-				for(var type in recipients){
-					result[type] = new Object;
-					result[type].label = type;
-					result[type].value = recipients[type];
-				}
-			}
 
 			// add data in result
-			result[tagName] = new Object;
-			result[tagName].label = properties[tagName];
-			result[tagName].value = xmlValue;
+			if(xmlValue != "") {
+				result[tagName] = new Object;
+				result[tagName].label = properties[tagName];
+				result[tagName].value = xmlValue;
+			}
 		}
 	}
+
+	var recipients = this.generateRecipientStringFromXML(message, false, false);
+	if (recipients){
+		for(var type in recipients){
+			result[type] = new Object;
+			result[type].label = type;
+			result[type].value = recipients[type];
+		}
+	}
+
+
 	return result;
 }
 
@@ -1396,7 +1410,7 @@ ItemModule.prototype.setInlineAttachmentData = function (attachments)
 			// Only for images files.
 			if (type && type.substring(0, type.indexOf('/')) == "image") {
 				this.inlineattachments[attachments[i]["attach_num"]] = new Object();
-				this.inlineattachments[attachments[i]["attach_num"]]["name"] = attachments[i]["name"];
+				this.inlineattachments[attachments[i]["attach_num"]]["name"] = attachments[i]["name"].htmlEntities();
 				this.inlineattachments[attachments[i]["attach_num"]]["cid"] = attachments[i]["cid"];
 				this.inlineattachments[attachments[i]["attach_num"]]["filetype"] = attachments[i]["filetype"];
 				
@@ -1648,11 +1662,10 @@ ItemModule.prototype.generateAttachmentStringFromXML = function(message)
 	var attachment = new Array();
 	var attachments = message.getElementsByTagName("attachment");
 	for(var i = 0; i < attachments.length; i++){
-		attachment.push(convertHtmlToPlain(dhtml.getXMLValue(attachments[i], "name", _("Untitled"))));
+		if(dhtml.getXMLValue(attachments[i], "hidden") != "1")
+			attachment.push(convertHtmlToPlain(dhtml.getXMLValue(attachments[i], "name", _("Untitled"))));
 	}
-	attachment.join(", ");
-	
-	return attachment;
+	return attachment.join(", ");
 }
 
 /**
