@@ -168,12 +168,16 @@ previewreadmailitemmodule.prototype.initializeView = function()
 	// So innerHTML used to create an iFrame.
 	// The javascript in the src attribute is to suppress the security warning in IE
 	
+
+	// Adding a scroller element to the page for iPad users
+	var scrollerStartHTML = '<div id="scroller" class="ipadscroller">';
+	var scrollerEndHTML = '</div>';
 	// WARNING THIS MEANS THAT ALL ELEMENT REFERENCES BEFORE THIS POINT BECOME INVALID
 	if (window.BROWSER_IE){
 		// SSL fix for IE
-		this.element.innerHTML += "<iframe id='html_body' frameborder='0' src=\"javascript:document.open();document.write('<html></html>');document.close();\"></iframe>";
+		this.element.innerHTML += scrollerStartHTML + "<iframe id='html_body' onload='linkifyDOM(this.contentDocument);' frameborder='0' src=\"javascript:document.open();document.write('<html></html>');document.close();\"></iframe>" + scrollerEndHTML;
 	}else{
-		this.element.innerHTML += "<iframe id='html_body' frameborder='0'></iframe>";
+		this.element.innerHTML += scrollerStartHTML + "<iframe id='html_body' onload='linkifyDOM(this.contentDocument);' frameborder='0'></iframe>" + scrollerEndHTML;
 	}	
 
 	var accept = dhtml.addElement(dhtml.getElementById("meetingrequest"), "span", "menubutton icon icon_accept", "accept", _("Accept"));
@@ -294,7 +298,7 @@ previewreadmailitemmodule.prototype.item = function(action)
 				// ...otherwise hide proposed time
 				dhtml.getElementById("meetingrequest_proposed_row").style.display = "none";
 			}
-			dhtml.getElementById("meetingrequest_location").innerHTML  = dhtml.getXMLValue(message, "location", "");
+			dhtml.addTextNode(dhtml.getElementById("meetingrequest_location"), dhtml.getXMLValue(message, "location", ""));
 
 			// Hide the "Remove From Calendar" button when this is not a Meeting Cancellation.
 			if(dhtml.getXMLValue(message,"message_class","").indexOf("IPM.Schedule.Meeting.Canceled") !== 0){
@@ -570,8 +574,11 @@ previewreadmailitemmodule.prototype.resize = function()
 
 	this.element.style.height = docHeight - dhtml.getElementTop(this.element) - 10 + "px";
 
+	// Both the body as the scroller element need to be resized.
 	var html_body = dhtml.getElementById("html_body");
+	var scrollerElem = document.getElementById('scroller');
 	if (html_body){
+		scrollerElem.style.width = (this.element.offsetWidth - 30) + "px";
 		html_body.style.width = (this.element.offsetWidth - 30) + "px";
 
 		var height = (this.element.offsetHeight - html_body.offsetTop) - 40;
@@ -579,6 +586,7 @@ previewreadmailitemmodule.prototype.resize = function()
 			height = 3;
 		}
 
+		scrollerElem.style.height = height + "px";
 		html_body.style.height = height + "px";
 	}
 }
@@ -590,7 +598,7 @@ previewreadmailitemmodule.prototype.resize = function()
 previewreadmailitemmodule.prototype.sendReadReceipt = function()
 {
 	var result = false;
-	if ((this.itemMessageFlags & MSGFLAG_RN_PENDING) == MSGFLAG_RN_PENDING){
+	if (((this.itemMessageFlags & MSGFLAG_READ) != MSGFLAG_READ) && (this.itemMessageFlags & MSGFLAG_RN_PENDING) == MSGFLAG_RN_PENDING){
 		switch(webclient.settings.get("global/readreceipt_handling", "ask")){
 			case "ask":
 				result = confirm(_("The sender of this message has asked to be notified when you read this message.")+"\n"+_("Do you wish to notify the sender?"));
