@@ -255,7 +255,7 @@ reminderlistmodule.prototype.showData = function()
 					break;
 				default:
 					if(typeof(itemData[colId])!="undefined"){
-						value = itemData[colId];
+						value = String(itemData[colId]).htmlEntities();
 					}else{
 						value = "&nbsp;";
 					}
