@@ -303,7 +303,7 @@ resolvenamesmodule.prototype.walkQue = function()
 		}
 	} else {
 		this.handler(this.returnList);
-		delete this.resolveQue;
-		delete this.returnList;
+		this.resolveQue = new Array();
+		this.returnList = new Array();
 	}
 }
