@@ -94,7 +94,8 @@ settingsmodule.prototype.get = function(path, default_value)
 	var tmp = this.settings;
 	for(var i=0; i<path.length; i++){
 		var pointer = path[i];
-		if (!tmp[pointer] && tmp[pointer] != 0) {
+		// Check whether value is not set to zero and if its empty then return default_value
+		if (!tmp[pointer] && (tmp[pointer] != 0 || tmp[pointer] === "")) {
 			if (typeof default_value == "undefined") {
 				return null;
 			}
