@@ -711,7 +711,7 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	}
 	
 	if(itemData["subject"] && itemData["subject"].firstChild) {
-		appointment.innerHTML += itemData["subject"].firstChild.nodeValue;
+		dhtml.addElement(appointment, "span", false, false, itemData["subject"].firstChild.nodeValue);
 		appointment.subject = itemData["subject"].firstChild.nodeValue;
 	}else{
 		appointment.innerHTML += "&nbsp;";
@@ -719,7 +719,7 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	}
 	
 	if(itemData["location"] && itemData["location"].firstChild) {
-		appointment.innerHTML += " (" + itemData["location"].firstChild.nodeValue + ")";
+		dhtml.addElement(appointment, "div", false, false, "(" + itemData["location"].firstChild.nodeValue + ")");
 		appointment.location = itemData["location"].firstChild.nodeValue;
 	}
 	
