@@ -124,7 +124,15 @@ CalendarMonthView.prototype.initView = function()
 	dhtml.addEvent(this.moduleID,nextButton,"click",eventMonthViewClickNext);	
 	nextButton.title = MONTHS[(this.selecteddate.getMonth()==11)?0:this.selecteddate.getMonth()+1];
 	
-	webclient.getModule(this.moduleID).setExtraTitle(extraElement);
+	// add keyboard event
+	var module = webclient.getModule(this.moduleID);
+	webclient.inputmanager.addObject(module, module.element);
+	
+	//Dont bind event if it is already binded earlier.
+	if (!webclient.inputmanager.hasEvent(module, "keydown", eventCalendarMonthViewKeyboard)) {
+		webclient.inputmanager.bindEvent(module, "keydown", eventCalendarMonthViewKeyboard);
+	}
+	module.setExtraTitle(extraElement);
 	
 	// get the date of the first day in the view
 	firstDayOfTheView = new Date(this.selecteddate);
@@ -197,8 +205,6 @@ CalendarMonthView.prototype.initView = function()
 			currentDay.addDays(1);
 		}
 	}
-	
-
 }
 
 CalendarMonthView.prototype.getStartEndTimeOfSelection = function(flag, element){
@@ -347,14 +353,14 @@ CalendarMonthView.prototype.createItem = function(item,element)
 	var unixTimeDue = item.getElementsByTagName("duedate")[0].getAttribute("unixtime");	
 	var startDate = new Date(unixTimeStart*1000);
 	var dueDate = new Date(unixTimeDue*1000);
-	var subject = dhtml.getTextNode(item.getElementsByTagName("subject")[0], NBSP);
-	var duration = dhtml.getTextNode(item.getElementsByTagName("duration")[0], 0);
-	var parent_entryid = item.getElementsByTagName("parent_entryid")[0].firstChild.nodeValue;
-	var entryid = item.getElementsByTagName("entryid")[0].firstChild.nodeValue;
+	var subject = dhtml.getXMLValue(item, "subject", NBSP);
+	var duration = dhtml.getXMLValue(item, "duration", 0);
+	var parent_entryid = dhtml.getXMLValue(item, "parent_entryid", "");
+	var entryid = dhtml.getXMLValue(item, "entryid", "");
 	var today = new Date(startDate);
 	var endday = new Date(dueDate);
-	var privateAppointment = dhtml.getTextNode(item.getElementsByTagName("private")[0], 0);
-	var privateSensitivity = dhtml.getTextNode(item.getElementsByTagName("sensitivity")[0], 0);
+	var privateAppointment = dhtml.getXMLValue(item, "private", NBSP);
+	var privateSensitivity = dhtml.getXMLValue(item, "sensitivity", NBSP);
 	
 	var AppointmentElement;
 	
@@ -572,7 +578,7 @@ function eventCalenderMonthViewDragDropTarget(moduleObject, targetElement, eleme
 	var moveOccAllowFlag = true;
 	if (element.meetingrequest && element.meetingrequest == olResponseOrganized) {
 		// Check whether there are any recepients in MR or not.
-		if(newDraggableDuedate>(new Date().getTime()/1000) && !(element.requestsent && element.requestsent != "1")) {
+		if(newDraggableDuedate>(new Date().getTime()/1000) && element.requestsent && element.requestsent == "1") {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 		}
 	}
@@ -622,3 +628,17 @@ function eventMonthViewClickNext(moduleObject, element, event)
 	datepickerlistmodule.changeMonth(timestamp.getMonth() + 1, timestamp.getFullYear(), true);
 	datepickerlistmodule.changeSelectedDate(timestamp.getTime(),true);
 }
+
+
+function eventCalendarMonthViewKeyboard(moduleObject, element, event)
+{
+	var viewObject = moduleObject.viewController.viewObject;
+	switch (event.keyCode){
+		case 37: // navigations keys
+			eventMonthViewClickPrev(moduleObject);
+			break;
+		case 39: // navigations keys
+			eventMonthViewClickNext(moduleObject);
+			break;
+	}
+}
\ No newline at end of file
