@@ -170,9 +170,18 @@ CalendarWeekView.prototype.initView = function()
 	var nextButton =dhtml.addElement(extraElement,"span","next_button","",NBSP);
 	dhtml.addEvent(this.moduleID,nextButton,"click",eventDayViewClickNext);
 	nextButton.title = _("Next week");
-	webclient.getModule(this.moduleID).setExtraTitle(extraElement);
 
-	this.resizeView()
+	// add keyboard event
+	var module = webclient.getModule(this.moduleID);
+	webclient.inputmanager.addObject(module, module.element);
+	
+	//Dont bind event if it is already binded earlier.
+	if (!webclient.inputmanager.hasEvent(module, "keydown", eventCalendarWeekViewKeyboard)) {
+		webclient.inputmanager.bindEvent(module, "keydown", eventCalendarWeekViewKeyboard);
+	}
+	module.setExtraTitle(extraElement);
+
+	this.resizeView();
 }
 
 /**
@@ -282,17 +291,17 @@ CalendarWeekView.prototype.createItem = function(item, element)
 	var dueDate = new Date(item.getElementsByTagName("duedate")[0].getAttribute("unixtime")*1000);
 	var unixTimeStart = item.getElementsByTagName("startdate")[0].getAttribute("unixtime");
 	var unixTimeDue = item.getElementsByTagName("duedate")[0].getAttribute("unixtime");	
-	var subject = item.getElementsByTagName("subject")[0].hasChildNodes()?item.getElementsByTagName("subject")[0].firstChild.nodeValue:NBSP;
-	var location = dhtml.getTextNode(item.getElementsByTagName("location")[0],"");
-	var duration = dhtml.getTextNode(item.getElementsByTagName("duration")[0], 0);
-	var parent_entryid = dhtml.getTextNode(item.getElementsByTagName("parent_entryid")[0],"");
-	var entryid = dhtml.getTextNode(item.getElementsByTagName("entryid")[0],"");
-	var label =  dhtml.getTextNode(item.getElementsByTagName("label")[0],"");
-	var recurring = dhtml.getTextNode(item.getElementsByTagName("recurring")[0],"");
+	var subject = dhtml.getXMLValue(item, "subject", NBSP);
+	var location = dhtml.getXMLValue(item, "location", NBSP);
+	var duration = dhtml.getXMLValue(item, "duration", 0);
+	var parent_entryid = dhtml.getXMLValue(item, "parent_entryid", ""); 
+	var entryid = dhtml.getXMLValue(item, "entryid", "");
+	var label =  dhtml.getXMLValue(item, "label", "");
+	var recurring = dhtml.getXMLValue(item, "recurring", "");
 	var basedate = item.getElementsByTagName("basedate")[0]?item.getElementsByTagName("basedate")[0].getAttribute("unixtime"):false;	
 	var exception = item.getElementsByTagName("exception")[0];
-	var privateAppointment = dhtml.getTextNode(item.getElementsByTagName("private")[0], 0);
-	var privateSensitivity = dhtml.getTextNode(item.getElementsByTagName("sensitivity")[0], 0);
+	var privateAppointment = dhtml.getXMLValue(item, "private", 0);
+	var privateSensitivity = dhtml.getXMLValue(item, "sensitivity", 0);
 
 	var today = new Date(startDate);
 	var endday = new Date(dueDate);
@@ -530,7 +539,7 @@ function eventCalenderWeekViewDragDropTarget(moduleObject, targetElement, elemen
 	var moveOccAllowFlag = true;
 	if (element.meetingrequest && element.meetingrequest == olResponseOrganized) {
 		// Check whether there are any recepients in MR or not.
-		if( newDraggableDuedate>(new Date().getTime()/1000) && !(element.requestsent && element.requestsent != "1")) {
+		if( newDraggableDuedate>(new Date().getTime()/1000) && element.requestsent && element.requestsent == "1") {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 		}
 	}
@@ -541,4 +550,17 @@ function eventCalenderWeekViewDragDropTarget(moduleObject, targetElement, elemen
 	if(moveOccAllowFlag){
 		moduleObject.save(props, send);
 	}
+}
+
+function eventCalendarWeekViewKeyboard(moduleObject, element, event)
+{
+	var viewObject = moduleObject.viewController.viewObject;
+	switch (event.keyCode){
+		case 37: // navigations keys
+			eventDayViewClickPrev(moduleObject);
+			break;
+		case 39: // navigations keys
+			eventDayViewClickNext(moduleObject);
+			break;
+	}
 }
\ No newline at end of file
