@@ -98,7 +98,6 @@ PrintCalendarWeekView.prototype.initView = function() {
  */
 PrintCalendarWeekView.prototype.resizeView = function(iframe) {
 	if(typeof iframe != "undefined") {
-		var iframe = window.frames["printing_frame"];
 		var iframeDoc = iframe.document;
 		var printFooterHeight = iframeDoc.getElementById("print_footer").offsetHeight;
 		var printHeaderHeight = iframeDoc.getElementById("print_header").offsetHeight;
@@ -130,7 +129,7 @@ PrintCalendarWeekView.prototype.resizeView = function(iframe) {
 	} else {
 		var menubarHeight = dhtml.getElementById("menubar").offsetHeight + dhtml.getElementById("menubar").offsetTop;
 		var titleHeight = dhtml.getElementsByClassName("title")[0].offsetHeight;
-		var bodyHeight = document.getElementsByTagName("body")[0].offsetHeight;
+		var bodyHeight = dhtml.getBrowserInnerSize()["y"];
 
 		var dialogContentHeight = bodyHeight - (menubarHeight + titleHeight) + 12;
 		dhtml.getElementById("dialog_content").style.height = dialogContentHeight + "px";
