@@ -775,32 +775,6 @@ TableView.prototype.renderColumn = function(table, name, title, type, length)
 	table.push("<td id='property_" + id + "' class='" + className + "' title='" + title + "' " + width + "><span class='column_seperator'>&nbsp;</span>" + elementValue + sort + "</td>");
 }
 
-/**
- * Function generates a string which will be used to show the recipients in list view's attendees coloumn.
- * @param number recipienttype number which contains the recipient type
- * @param object item object xml data of each item
- * @return string result string which contains the recipients name and email
- */
-TableView.prototype.generateRecipientStringFromXML = function(recipienttype, item)
-{	
-	var result = "";
-	var recipients = item.getElementsByTagName("recipients")[0];
-
-	if(recipients){	
-		var recipient = recipients.getElementsByTagName("recipient");
-		for (var j = 0; j < recipient.length; j++){		
-			var type = dhtml.getXMLValue(recipient[j], "type");
-			var name = dhtml.getXMLValue(recipient[j], "display_name");
-			var email = dhtml.getXMLValue(recipient[j], "email_address");
-
-			if(parseInt(type,10) == recipienttype){
-				result += (result=="")?nameAndEmailToString(name, email, true) + ";": nameAndEmailToString(name, email, true);
-			}
-		}
-	}
-	return result;
-}
-
 TableView.prototype.renderRowColumn = function(table, fieldname, type, length, value, item,rowNumber)
 {
 	var settings = this.getRowColumnSettings(fieldname, type, length, value, item);
@@ -1009,12 +983,12 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 
 			switch(parseInt(value,10))
 			{
-				case 0:
+				case IMPORTANCE_LOW:
 					className += "icon_importance_low";
 					title = _("Low");
 					break;
 					
-				case 1:
+				case IMPORTANCE_NORMAL:
 					/**
 					 * We want dropdown arrow for Normal Priority
 					 * only in those list which has Quickitem ability.
@@ -1025,7 +999,7 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 					}
 					break;
 					
-				case 2:
+				case IMPORTANCE_HIGH:
 					className += "icon_importance_high";
 					title = _("High");
 					break;		
@@ -1092,72 +1066,69 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 					checked = "checked='checked'";
 			}
 			elementValue = "<input type='checkbox' disabled='disabled' " + checked + ">";	
-			break;	
-		
-		//to display busy status as a string 		
-		case "meeting":
-		var responsestatus = dhtml.getXMLValue(item, "responsestatus");
-		var meeting = dhtml.getXMLValue(item, "meeting");
-			if(parseInt(meeting,10) == 0){
-				elementValue = "<div class='rowcolumntext'></div>";		
-			}else{ 
-				switch(parseInt(responsestatus,10))
-				{
-					case 0:
-					elementValue = "<div class='rowcolumntext'>"+ _("No Response")+"</div>";		
-					break;
-						
-					case 1:
-					elementValue = "<div class='rowcolumntext'>"+ _("Meeting Organizer")+"</div>";
-					break;	
-						
-					case 2:
-					elementValue = "<div class='rowcolumntext'>"+ _("Tentatively Accepted")+"</div>";
-					break;	
-						
-					case 3:
-					elementValue = "<div class='rowcolumntext'>"+ _("Accepted")+"</div>";
-					break;	
-	
-					case 4:
-					elementValue = "<div class='rowcolumntext'>"+ _("Declined")+"</div>";
-					break;	
-				
-					case 5:
-					elementValue = "<div class='rowcolumntext'>"+ _("Not Yet Responded")+"</div>";
-					break;	
-					
-					default:
-					elementValue = "<div class='rowcolumntext'></div>";
-					break;
-				}
-			}	
-			width = 150;
 			break;
+
+		// to display meeting status as a string
+		case "meeting":
+			var responsestatus = dhtml.getXMLValue(item, "responsestatus");
+			var meeting = dhtml.getXMLValue(item, "meeting");
+				if(parseInt(meeting,10) == 0){
+					elementValue = "<div class='rowcolumntext'></div>";		
+				}else{ 
+					switch(parseInt(responsestatus,10))
+					{
+						case olResponseNone:
+							elementValue = "<div class='rowcolumntext'>"+ _("No Response")+"</div>";
+							break;
+
+						case olResponseOrganized:
+							elementValue = "<div class='rowcolumntext'>"+ _("Meeting Organizer")+"</div>";
+							break;
+
+						case olResponseTentative:
+							elementValue = "<div class='rowcolumntext'>"+ _("Tentatively Accepted")+"</div>";
+							break;	
+							
+						case olResponseAccepted:
+							elementValue = "<div class='rowcolumntext'>"+ _("Accepted")+"</div>";
+							break;	
+		
+						case olResponseDeclined:
+							elementValue = "<div class='rowcolumntext'>"+ _("Declined")+"</div>";
+							break;	
+					
+						case olResponseNotResponded:
+							elementValue = "<div class='rowcolumntext'>"+ _("Not Yet Responded")+"</div>";
+							break;	
+						
+						default:
+							elementValue = "<div class='rowcolumntext'></div>";
+							break;
+					}
+				}	
+				width = 150;
+				break;
 		
 			//busystatus
 			case "busystatus":
-			switch(parseInt(value,10))
-			{
-				case 0:
-				elementValue = "<div class='rowcolumntext'>"+ _("Free")+"</div>";
-				break; 
-
-				case 1:
-				elementValue = "<div class='rowcolumntext'>"+ _("Tentative")+"</div>"; 
+				switch(parseInt(value,10))
+				{
+					case fbFree:
+						elementValue = "<div class='rowcolumntext'>"+ _("Free")+"</div>";
+						break; 
+					case fbTentative:
+						elementValue = "<div class='rowcolumntext'>"+ _("Tentative")+"</div>"; 
+						break;
+					case fbBusy:
+						elementValue = "<div class='rowcolumntext'>"+ _("Busy")+"</div>"; 
+						break;
+					case fbOutOfOffice:
+						elementValue = "<div class='rowcolumntext'>"+ _("Out of Office")+"</div>";
+						break
+				}
+				width = 150; 
 				break;
 
-				case 2:
-				elementValue = "<div class='rowcolumntext'>"+ _("Busy")+"</div>"; 
-				break;
-
-				case 3:
-				elementValue = "<div class='rowcolumntext'>"+ _("Out of Office")+"</div>";
-				break
-			}
-			width =150; 
-			break;
-
 		//label
 		case "label":
 			switch(parseInt(value,10))
@@ -1215,46 +1186,30 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 		//sensitivity	
 		case "sensitivity":
 			switch(parseInt(value,10))
-			{	
-				case 0:
-				elementValue = "<div class='rowcolumntext'>"+ _("Normal") +"</div>";		
-				break;
-					
-				case 1:
-				elementValue = "<div class='rowcolumntext'>"+ _("Personal")+"</div>";
-				break;	
-					
-				case 2:
-				elementValue = "<div class='rowcolumntext'>"+ _("Private")+"</div>";
-				break;	
-					
-				case 3:
-				elementValue = "<div class='rowcolumntext'>"+ _("Confidential")+"</div>";
-				break;	
-				
+			{
+				case SENSITIVITY_NONE:
+					elementValue = "<div class='rowcolumntext'>"+ _("Normal") +"</div>";
+					break;
+
+				case SENSITIVITY_PERSONAL:
+					elementValue = "<div class='rowcolumntext'>"+ _("Personal")+"</div>";
+					break;
+
+				case SENSITIVITY_PRIVATE:
+					elementValue = "<div class='rowcolumntext'>"+ _("Private")+"</div>";
+					break;
+
+				case SENSITIVITY_COMPANY_CONFIDENTIAL:
+					elementValue = "<div class='rowcolumntext'>"+ _("Confidential")+"</div>";
+					break;
+
 				default:
-				elementValue = "<div class='rowcolumntext'></div>";
-				break;
+					elementValue = "<div class='rowcolumntext'></div>";
+					break;
 			}
 			width = 150;
 			break;
-			
-		//attendee
-		case "required":
-			elementValue = "<div class='rowcolumntext'>"+this.generateRecipientStringFromXML(MAPI_TO, item)+"<div>" ;
-			width = 150;
-			break;
-			
-		case "optional":
-			elementValue = "<div class='rowcolumntext'>"+this.generateRecipientStringFromXML(MAPI_CC, item)+"<div>" ;
-			width = 150;
-			break;
-			
-		case "resource":
-			elementValue = "<div class='rowcolumntext'>"+this.generateRecipientStringFromXML(MAPI_BCC, item)+"<div>" ;
-			width = 150;
-			break;	
-		
+
 		default:
 			// fix any HTML characters, because value will be added directly to innerHTML
 			// known bug: if a subject only contains "&nbsp;" it wouldn't display
