@@ -253,6 +253,9 @@ TodayCalendarView.prototype.getDateTimeOfAppointment = function(data){
 	var dueTime = strftime(_('%H:%M'),dueDateUnixtime).toUpperCase();
 	var dueDate = strftime('%d-%m-%Y',dueDateUnixtime);
 
+	// To avoid showing single day appoitments which completes 24:00hrs as a "Multi day appointments"
+	var preferredDueDate = strftime('%d-%m-%Y',dueDateUnixtime - 1);
+
 	var currentUnixTime = parseInt(new Date().getTime() / 1000);
 	if(dueDateUnixtime < currentUnixTime && startDate == dueDate) {
 		//for expire time 
@@ -260,7 +263,7 @@ TodayCalendarView.prototype.getDateTimeOfAppointment = function(data){
 	} else if(allday) {
 		//for all day event
 		return [_("All day event"), "alldayevent"];
-	} else if(startDate != dueDate) { 
+	} else if(startDate != preferredDueDate) { 
 		//for multi day event
 		return [_("Multi-day event"), "alldayevent"];
 	} else {
