@@ -168,7 +168,7 @@ TodayTaskView.prototype.updateItem = function(element, item, properties)
 
 	var property = new Object();
 	property["complete"] = dhtml.getXMLValue(item, "complete", 0);
-	property["subject"] = dhtml.getXMLValue(item, "subject", "");
+	property["subject"] = dhtml.getXMLValue(item, "subject", "").htmlEntities();
 	property["importance"] = dhtml.getXMLValue(item, "importance", 1);
 
 	for(var prop in property){
@@ -256,7 +256,7 @@ TodayTaskView.prototype.getRowColumnSettings = function(type, value, item)
 			value = NBSP;
 			break;
 		case "subject":
-			var subject = dhtml.getXMLValue(item, "subject", "");
+			var subject = dhtml.getXMLValue(item, "subject", "").htmlEntities();
 			var duedate = dhtml.getXMLValue(item, "duedate", false);
 
 			value = "<span>"+ subject + NBSP + (duedate? "("+ strftime('%d/%m/%Y', duedate) +")": "("+ _("None") +")") +"</span>";
