@@ -86,6 +86,14 @@
 		<!--[if IE]>
 		<link rel="stylesheet" type="text/css" href="client/layout/css/style.ie.css">
 		<![endif]-->
+<?php
+	// Apply an iPad specific stylesheet when needed
+	if(strpos($_SERVER['HTTP_USER_AGENT'], 'iPad') !== false){
+?>
+		<link rel="stylesheet" type="text/css" href="client/layout/css/style.ipad.css">
+<?php
+	}
+?>
 		<link rel="icon" href="client/layout/img/favicon.ico"  type="image/x-icon">
 		<link rel="shortcut icon" href="client/layout/img/favicon.ico" type="image/x-icon">	
 <?php
@@ -174,6 +182,10 @@
 			var DIALOG_URL = "<?=DIALOG_URL?>";
 			var MUC_AVAILABLE =<?=(defined('MUC_AVAILABLE')&&MUC_AVAILABLE==true)?'true':'false'?>;
 			var SSO_LOGIN =<?=(isset($_SERVER['REMOTE_USER']))?'true':'false'?>;
+			var NAMEDPROPS = {
+				'PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords' : "<?=convertStringToHexNamedPropId('PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords')?>",
+				'PT_STRING8:PS_PUBLIC_STRINGS:Keywords' : "<?=convertStringToHexNamedPropId('PT_STRING8:PS_PUBLIC_STRINGS:Keywords')?>"
+			};
 
 			<?php if(checkTrialVersion()){ ?>
 			var ZARAFA_TRIAL_EXPIRE_PERIOD = <?=getDaysLeftOnTrialPeriod();?>; 
@@ -217,7 +229,8 @@
 
 				// Store current sessionid in sessionid variable
 				webclient.sessionid = "<?=session_id()?>";
-				webclient.init("<?=BASE_URL?>", "webclient", modules, settings, plugindata);
+				// Add a timestamp to the modulePrefix "webclient" to prevent conflicting moduleIDs with multiple tabs
+				webclient.init("<?=BASE_URL?>", "webclient"+(new Date()).getTime(), modules, settings, plugindata);
 				webclient.startClient();
 			}
 		</script>
