@@ -89,4 +89,10 @@ if(!defined('ENABLE_MULTI_UPLOAD')) define('ENABLE_MULTI_UPLOAD', false);
  */
 if(!defined('ABITEMDETAILS_MAX_NUM_DISTLIST_MEMBERS')) define('ABITEMDETAILS_MAX_NUM_DISTLIST_MEMBERS', 0);
 
+/**
+ * Use direct booking by default (books resources directly in the calendar instead of sending a meeting
+ * request)
+ */
+if(!defined('ENABLE_DIRECT_BOOKING')) define('ENABLE_DIRECT_BOOKING', true);
+
 ?>
