@@ -82,6 +82,11 @@
 		 */
 		var $recur;
 
+		/**
+		 * @var Timezone data of this calendar item
+		 */
+		var $tz;
+
 		/**
 		 * Constructor
 		 * @param resource $store MAPI Message Store Object
@@ -99,15 +104,17 @@
 				$this->messageprops = mapi_getprops($this->message, $this->proptags);
 			}
 
-			if(isset($this->messageprops[$this->proptags["recurring_data"]]))
+			if(isset($this->messageprops[$this->proptags["recurring_data"]])) {
 				// There is a possibility that recurr blob can be more than 255 bytes so get full blob through stream interface
 				if (strlen($this->messageprops[$this->proptags["recurring_data"]]) >= 255) {
 					$this->getFullRecurrenceBlob();
 				}
 
 				$this->recur = $this->parseRecurrence($this->messageprops[$this->proptags["recurring_data"]]);
-			if(isset($this->proptags["timezone_data"]) && isset($this->messageprops[$this->proptags["timezone_data"]]))
+			}
+			if(isset($this->proptags["timezone_data"]) && isset($this->messageprops[$this->proptags["timezone_data"]])) {
 				$this->tz = $this->parseTimezone($this->messageprops[$this->proptags["timezone_data"]]);
+			}
 		}
 
 		function getRecurrence()
@@ -123,10 +130,13 @@
 			$stream = mapi_openproperty($message, $this->proptags["recurring_data"], IID_IStream, 0, 0);
 			$stat = mapi_stream_stat($stream);
 
-			for ($i = 0; $i < $stat['cb']; $i += 1024)
+			for ($i = 0; $i < $stat['cb']; $i += 1024) {
 				$recurrBlob .= mapi_stream_read($stream, 1024);
+			}
 
-			if (!empty($recurrBlob)) $this->messageprops[$this->proptags["recurring_data"]] = $recurrBlob;
+			if (!empty($recurrBlob)) {
+				$this->messageprops[$this->proptags["recurring_data"]] = $recurrBlob;
+			}
 		}
 
 		/**
@@ -681,18 +691,22 @@
 						if(($dayofweek < $weekstart && $dayskip > 0) || ($dayofweek+$dayskip) > 6)
 							$weekskip = 1;
 
-						// $weekskip is the amount of weeks to skip from the startdate before the first occurence
-						// $forwardcount is the maximum number of week occurrences we can go ahead after the first occurrence that
-						// is still inside the recurrence. We subtract one to make sure that the last week is never forwarded over
-						// (eg when numoccur = 2, and daycount = 1)
-						$forwardcount = floor( intval($this->recur["numoccur"] -1 ) / $daycount);
+						// Check if the recurrence ends after a number of occurences, in that case we must calculate the
+						// remaining occurences based on the start of the recurrence.
+						if (intval($this->recur["term"]) == 0x22) {
+							// $weekskip is the amount of weeks to skip from the startdate before the first occurence
+							// $forwardcount is the maximum number of week occurrences we can go ahead after the first occurrence that
+							// is still inside the recurrence. We subtract one to make sure that the last week is never forwarded over
+							// (eg when numoccur = 2, and daycount = 1)
+							$forwardcount = floor( intval($this->recur["numoccur"] -1 ) / $daycount);
 
-						// $restocc is the number of occurrences left after $forwardcount whole weeks of occurrences, minus one
-						// for the occurrence on the first day
-						$restocc = intval($this->recur["numoccur"]) - ($forwardcount*$daycount) - 1; 
+							// $restocc is the number of occurrences left after $forwardcount whole weeks of occurrences, minus one
+							// for the occurrence on the first day
+							$restocc = intval($this->recur["numoccur"]) - ($forwardcount*$daycount) - 1; 
 
-						// $forwardcount is now the number of weeks we can go forward and still be inside the recurrence
-						$forwardcount *= intval($this->recur["everyn"]);
+							// $forwardcount is now the number of weeks we can go forward and still be inside the recurrence
+							$forwardcount *= intval($this->recur["everyn"]);
+						}
 						
 						// The real start is start + dayskip + weekskip-1 (since dayskip will already bring us into the next week)
 						$this->recur["start"] = intval($this->recur["start"]) + ($dayskip * 24*60*60)+ ($weekskip *(intval($this->recur["everyn"]) - 1) * 7 * 24*60*60);
@@ -729,10 +743,14 @@
 					$curmonthday = gmdate("j", intval($this->recur["start"]) );
 					$curyear = gmdate("Y", intval($this->recur["start"]) );
 					$curmonth = gmdate("n", intval($this->recur["start"]) );
-					
-					// $forwardcount is the number of occurrences we can skip and still be inside the recurrence range (minus
-					// one to make sure there are always at least one occurrence left)
-					$forwardcount = ((intval($this->recur["numoccur"])-1) * $everyn );
+
+					// Check if the recurrence ends after a number of occurences, in that case we must calculate the
+					// remaining occurences based on the start of the recurrence.
+					if (intval($this->recur["term"]) == 0x22) {
+						// $forwardcount is the number of occurrences we can skip and still be inside the recurrence range (minus
+						// one to make sure there are always at least one occurrence left)
+						$forwardcount = ((intval($this->recur["numoccur"])-1) * $everyn );
+					}
 					
 					// Get month for yearly on D'th day of month M
 					if($term == 0x0D /*yearly*/) {
@@ -1204,19 +1222,34 @@
 			}
 
 			// FlagDueBy is datetime of the first reminder occurrence. Outlook gives on this time a reminder popup dialog
-			$reminderprops = mapi_getprops($this->message, array($this->proptags["reminder_minutes"], $this->proptags["flagdueby"]) );
+			// Any change of the recurrence (including changing and deleting exceptions) causes the flagdueby to be reset
+			// to the 'next' occurrence; this makes sure that deleting the next ocurrence will correctly set the reminder to
+			// the occurrence after that. The 'next' occurrence is defined as being the first occurrence that starts at moment X (server time)
+			// with the reminder flag set.
+			$reminderprops = mapi_getprops($this->message, array($this->proptags["reminder_minutes"]) );
 			if(isset($reminderprops[$this->proptags["reminder_minutes"]]) ) {
-				/**
-				 * TODO: $utcfirstoccstartdatetime must the first upcomming occurrence, so you need the current 
--				 * client time. When you create a recurrent before the current date, the FlagDueBy must be the 
--				 * first upcomming occurrence after the current date.
-				 * 
-				 * Get the next occurrence after the current flagdueby i.e. reminder and set that occurrence's
-				 * reminder time to the flagdueby property.
-				 */
-				$items = $this->getItems($reminderprops[$this->proptags["flagdueby"]], 0x7ff00000, 1, true);
-				$tempnextreminder = $items[0][$this->proptags["startdate"]] - ( $items[0][$this->proptags["reminder_minutes"]] * 60 );
-				mapi_setprops($this->message, Array($this->proptags["flagdueby"] => $tempnextreminder ));
+			    $occ = false;
+			    $occurrences = $this->getItems(time(), 0x7ff00000, 3, true);
+
+                for($i = 0 ; $i < count($occurrences); $i++) {
+                    // This will actually also give us appointments that have already started, but not yet ended. Since we want the next
+                    // reminder that occurs after time(), we may have to skip the first few entries. We get 3 entries since that is the maximum
+                    // number that would be needed (assuming reminder for item X cannot be before the previous occurrence starts). Worst case:
+                    // time() is currently after start but before end of item, but reminder of next item has already passed (reminder for next item
+                    // can be DURING the previous item, eg daily allday events). In that case, the first and second items must be skipped.
+
+			        if(($occurrences[$i][$this->proptags["startdate"]] - $reminderprops[$this->proptags["reminder_minutes"]] * 60) > time()) {
+			            $occ = $occurrences[$i];
+			            break;
+                    }
+			    }
+			    
+			    if($occ) {
+    				mapi_setprops($this->message, Array($this->proptags["flagdueby"] => $occ[$this->proptags["startdate"]] - ($reminderprops[$this->proptags["reminder_minutes"]] * 60) ));
+                } else {
+                    // Last reminder passed, no reminders any more.
+                    mapi_setprops($this->message, Array($this->proptags["reminder"] => false, $this->proptags["flagdueby"] => 0x7ff00000));
+                }
 			}
 			
 			// Default data
@@ -1499,7 +1532,7 @@
 			$dststart = $this->getDateByYearMonthWeekDayHour($gmdate["tm_year"], $tz["dststartmonth"], $tz["dststartweek"], 0, $tz["dststarthour"]);
 			$dstend = $this->getDateByYearMonthWeekDayHour($gmdate["tm_year"], $tz["dstendmonth"], $tz["dstendweek"], 0, $tz["dstendhour"]);
 
-			if($dststart < $dstend) {
+			if($dststart <= $dstend) {
 				// Northern hemisphere, eg DST is during Mar-Oct
 				if($date > $dststart && $date < $dstend) {
 					$dst = true;
@@ -1628,7 +1661,9 @@
 
 
 		/**
-		 * Function which returns the items in a given interval.
+		 * Function which returns the items in a given interval. This included expansion of the recurrence and 
+		 * processing of exceptions (modified and deleted).
+		 *
 		 * @param string $entryid the entryid of the message
 		 * @param array $props the properties of the message
 		 * @param date $start start time of the interval (GMT)
