@@ -323,6 +323,7 @@ class FreeBusyPublish {
     	$csubj = Array();
     	$cbusy = Array();
     	$level = 0;
+		$laststart = null;
 
     	foreach($items as $item)
     	{
@@ -342,7 +343,8 @@ class FreeBusyPublish {
     	usort($timestamps, Array($this, "cmp"));
 
     	foreach($timestamps as $ts)
-    	{
+		{
+
     		switch ($ts["type"])
     		{
     			case 0: // Start
