@@ -345,62 +345,49 @@
 		}
 
 		/**
-		 * Check to see reminder time does not exceed the starttime
-		 * of the previous recurring item
+		 * Check to see if the exception proposed at a certain basedate is allowed concerning reminder times:
+		 *
+		 * Both must be true:
+		 * - reminder time of this item is not before the starttime of the previous recurring item
+		 * - reminder time of the next item is not before the starttime of this item
 		 *
 		 * @param date $basedate the base date of the exception (LOCAL time of non-exception occurrence)
 		 * @param string $reminderminutes reminder minutes which is set of the item
 		 * @param date $startdate the startdate of the selected item
-		 * @returns boolean if the reminder minutes value valid.
+		 * @returns boolean if the reminder minutes value valid (FALSE if either of the rules above are FALSE)
 		 */
 		function isValidReminderTime($basedate, $reminderminutes, $startdate)
 		{
 			$isreminderrangeset = false;
 			
 			// get all occurence items before the seleceted items occurence starttime
-			$occitems = $this->getItems($this->messageprops[$this->proptags["startdate"]], $basedate);
-			$len = count($occitems);
+			$occitems = $this->getItems($this->messageprops[$this->proptags["startdate"]], $this->toGMT($this->tz, $basedate));
 			
-			// as occitems array is sorted in ascending order of startdate so, to get the previous occurence we take the second last items in occitems .
-			$previousitem_basedate = $occitems[$len - 1]["basedate"];	//previous basedate in local format
-			$previousitem_startdate = $this->toGMT($this->tz, ($previousitem_basedate + ($this->recur["startocc"] * 60)));	//previous startdate in GMT timezone
+			if(count($occitems) > 0) {
+				// as occitems array is sorted in ascending order of startdate, to get the previous occurence we take the last items in occitems .
+				$previousitem_startdate = $occitems[count($occitems) - 1][$this->proptags["startdate"]];
 
-			if(count($this->recur["changed_occurences"] > 0)){
-				
-				for($i=0 ;$i<count($this->recur["changed_occurences"]); $i++) {
-					//check that whether the previous occurence is already a exceptions
-					if($this->isSameDay($this->recur["changed_occurences"][$i]["basedate"], $previousitem_basedate)){
-						$previousitem_startdate = $this->toGMT($this->tz, $this->recur["changed_occurences"][$i]["start"]);	// in GMT timezone
-						
-						$reminderrange = ($startdate - $previousitem_startdate)/60;
-						$isreminderrangeset = true;
-					}
-				}
-			}else{
-				$reminderrange = ($startdate - $previousitem_startdate)/60;
-				$isreminderrangeset = true;
+				// if our reminder is set before or equal to the beginning of the previous occurrence, then that's not allowed
+				if($startdate - ($reminderminutes*60) <= $previousitem_startdate)
+					return false;
 			}
+			
+			// Get the endtime of the current occurrence and find the next two occurrences (including the current occurrence)
+			$currentOcc = $this->getItems($this->toGMT($this->tz, $basedate), 0x7ff00000, 2, true);
 
-			if(!$isreminderrangeset)	
-				$reminderrange = ($startdate - $previousitem_startdate)/60;
-
-			// Get the endtime of the current occurrence and find the next occurrence of the current moved occurrence.
-			$currentOcc = $this->getItems($basedate, 0x7ff00000, 1, true);
-			$currentOccEnd = $currentOcc[0][$this->proptags["duedate"]];
-			$nextOcc = $this->getItems($currentOccEnd, 0x7ff00000, 1, true);
-
-			if(count($nextOcc) > 0) {
+			// If there are another two occurrences, then the first is the current occurrence, and the one after that
+			// is the next occurrence.
+			if(count($currentOcc) > 1) {
+				$next = $currentOcc[1];
 				// Get reminder time of the next occurrence.
-				$nextOccReminderTime = $nextOcc[0][$this->proptags["startdate"]] - ($nextOcc[0][$this->proptags["reminder_minutes"]] * 60);
-				// Check that the occurrence doesn't start after the next occurrence reminder.
-				if($nextOccReminderTime < $startdate)
+				$nextOccReminderTime = $next[$this->proptags["startdate"]] - ($next[$this->proptags["reminder_minutes"]] * 60);
+				// If the reminder time of the next item is before the start of this item, then that's not allowed
+				if($nextOccReminderTime <= $startdate)
 					return false;
 			}
 
-			if($reminderminutes >= $reminderrange)
-				return false;
-			else
-				return true;
+			// All was ok
+			return true;
 		}
 		
 		function setRecurrence($tz, $recur) 
@@ -499,89 +486,9 @@
 		 * @param $rows array Array of rowdata as if they were returned directly from mapi_table_queryrows. Each recurring item is
 		 *                    expanded so that it seems that there are only many single appointments in the table.
 		 */
-		function getCalendarItems($store, $calendar, $viewstart, $viewend, $propsrequested)
+		static function getCalendarItems($store, $calendar, $viewstart, $viewend, $propsrequested)
 		{
-		    $result = array();
-            $properties = getPropIdsFromStrings($store, Array( "duedate" => "PT_SYSTIME:PSETID_Appointment:0x820e",
-                                                       "startdate" =>  "PT_SYSTIME:PSETID_Appointment:0x820d",
-                                                       "enddate_recurring" => "PT_SYSTIME:PSETID_Appointment:0x8236",
-                                                       "recurring" => "PT_BOOLEAN:PSETID_Appointment:0x8223",
-                                                       "recurring_data" => "PT_BINARY:PSETID_Appointment:0x8216",
-                                                       "timezone_data" => "PT_BINARY:PSETID_Appointment:0x8233",
-                                                       "label" => "PT_LONG:PSETID_Appointment:0x8214"
-                                                        ));
-                                                        
-            // Create a restriction that will discard rows of appointments that are definitely not in our
-            // requested time frame
-		    
-		    $table = mapi_folder_getcontentstable($calendar);
-		    
-            $restriction = 
-                // OR
-                Array(RES_OR,
-                         Array(
-                               Array(RES_AND,	// Normal items: itemEnd must be after viewStart, itemStart must be before viewEnd
-                                     Array(
-                                           Array(RES_PROPERTY,
-                                                 Array(RELOP => RELOP_GT,
-                                                       ULPROPTAG => $properties["duedate"],
-                                                       VALUE => $viewstart
-                                                       )
-                                                 ),
-                                           Array(RES_PROPERTY,
-                                                 Array(RELOP => RELOP_LT,
-                                                       ULPROPTAG => $properties["startdate"],
-                                                       VALUE => $viewend
-                                                       )
-                                                 )
-                                           )
-                                     ),
-                               // OR
-                               Array(RES_PROPERTY,
-                                     Array(RELOP => RELOP_EQ,
-                                           ULPROPTAG => $properties["recurring"],
-                                           VALUE => true
-                                           )
-                                     )
-                               ) // EXISTS OR
-                         );		// global OR
-
-            // Get requested properties, plus whatever we need		    
-            $proplist = array($properties["recurring"], $properties["recurring_data"], $properties["timezone_data"]);
-            $proplist = array_merge($proplist, $propsrequested);
-            $propslist = array_unique($proplist);
-		    
-            $rows = mapi_table_queryallrows($table, $proplist, $restriction);
-            
-            // $rows now contains all the items that MAY be in the window; a recurring item needs expansion before including in the output.
-            
-            foreach($rows as $row) {
-                $items = array();
-                
-                if(isset($row[$properties["recurring"]]) && $row[$properties["recurring"]]) {
-                    // Recurring item
-                    $rec = new Recurrence($store, $row);
-
-                    // GetItems guarantees that the item overlaps the interval <$viewstart, $viewend>                    
-                    $occurrences = $rec->getItems($viewstart, $viewend);
-                    foreach($occurrences as $occurrence) {
-                        // The occurrence takes all properties from the main row, but overrides some properties (like start and end obviously)
-                        $item = $row;
-                        array_merge($item, $occurrence);
-                        array_push($items, $item);
-                    }
-                    
-                } else {
-                    // Normal item, it matched the search criteria and therefore overlaps the interval <$viewstart, $viewend>
-                    array_push($items, $row);
-                }
-                
-                $result = array_merge($result,$items);
-            }
-            
-            // All items are guaranteed to overlap the interval <$viewstart, $viewend>. Note that we may be returning a few extra
-            // properties that the caller did not request (recurring, etc). This shouldn't be a problem though.
-            return $result;
+			return getCalendarItems($store, $calendar, $viewstart, $viewend, $propsrequested);
 		}
 
 
@@ -944,10 +851,13 @@
 		function setExceptionRecipients($message, $exception_recips)
 		{
 			$deletedRecipients = array();
+			$useMessageRecipients = false;
+
 			$recipientTable = mapi_message_getrecipienttable($message);
 			$recipientRows = mapi_table_queryallrows($recipientTable, array(PR_ENTRYID, PR_DISPLAY_NAME, PR_EMAIL_ADDRESS, PR_RECIPIENT_ENTRYID, PR_RECIPIENT_TYPE, PR_SEND_INTERNET_ENCODING, PR_SEND_RICH_INFO, PR_RECIPIENT_DISPLAY_NAME, PR_ADDRTYPE, PR_DISPLAY_TYPE, PR_RECIPIENT_TRACKSTATUS, PR_RECIPIENT_FLAGS, PR_ROWID));
 
 			if (count($recipientRows) == 0) {
+				$useMessageRecipients = true;
 				$recipientTable = mapi_message_getrecipienttable($this->message);
 				$recipientRows = mapi_table_queryallrows($recipientTable, array(PR_ENTRYID, PR_DISPLAY_NAME, PR_EMAIL_ADDRESS, PR_RECIPIENT_ENTRYID, PR_RECIPIENT_TYPE, PR_SEND_INTERNET_ENCODING, PR_SEND_RICH_INFO, PR_RECIPIENT_DISPLAY_NAME, PR_ADDRTYPE, PR_DISPLAY_TYPE, PR_RECIPIENT_TRACKSTATUS, PR_RECIPIENT_FLAGS, PR_ROWID));
 			}
@@ -982,8 +892,15 @@
 						}
 					}
 
-					// First remove this recipient from message
-					mapi_message_modifyrecipients($message, MODRECIP_REMOVE, array($recipient));
+					// When $message contains a non-empty recipienttable, we must delete the recipients
+					// before re-adding them. However, when $message is doesn't contain any recipients,
+					// we are using the recipient table of the original message ($this->message)
+					// rather then $message. In that case, we don't need to remove the recipients
+					// from the $message, as the recipient table is already empty, and
+					// mapi_message_modifyrecipients() will throw an error.
+					if ($useMessageRecipients === false) {
+						mapi_message_modifyrecipients($message, MODRECIP_REMOVE, array($recipient));
+					}
 				}
 				$exception_recips = array_merge($exception_recips, $deletedRecipients);
 			} else {
