@@ -233,4 +233,103 @@ function DTE_REMOTE($value) {
 function DTE_LOCAL($value) {
 	return ($value & DTE_MASK_LOCAL);
 }
-?>
\ No newline at end of file
+
+/**
+ * Note: Static function, more like a utility function.
+ *
+ * Gets all the items (including recurring items) in the specified calendar in the given timeframe. Items are
+ * included as a whole if they overlap the interval <$start, $end> (non-inclusive). This means that if the interval
+ * is <08:00 - 14:00>, the item [6:00 - 8:00> is NOT included, nor is the item [14:00 - 16:00>. However, the item
+ * [7:00 - 9:00> is included as a whole, and is NOT capped to [8:00 - 9:00>.
+ *
+ * @param $store resource The store in which the calendar resides
+ * @param $calendar resource The calendar to get the items from
+ * @param $viewstart int Timestamp of beginning of view window
+ * @param $viewend int Timestamp of end of view window
+ * @param $propsrequested array Array of properties to return
+ * @param $rows array Array of rowdata as if they were returned directly from mapi_table_queryrows. Each recurring item is
+ *                    expanded so that it seems that there are only many single appointments in the table.
+ */
+function getCalendarItems($store, $calendar, $viewstart, $viewend, $propsrequested){
+	$result = array();
+	$properties = getPropIdsFromStrings($store, Array( "duedate" => "PT_SYSTIME:PSETID_Appointment:0x820e",
+											   "startdate" =>  "PT_SYSTIME:PSETID_Appointment:0x820d",
+											   "enddate_recurring" => "PT_SYSTIME:PSETID_Appointment:0x8236",
+											   "recurring" => "PT_BOOLEAN:PSETID_Appointment:0x8223",
+											   "recurring_data" => "PT_BINARY:PSETID_Appointment:0x8216",
+											   "timezone_data" => "PT_BINARY:PSETID_Appointment:0x8233",
+											   "label" => "PT_LONG:PSETID_Appointment:0x8214"
+												));
+												
+	// Create a restriction that will discard rows of appointments that are definitely not in our
+	// requested time frame
+	
+	$table = mapi_folder_getcontentstable($calendar);
+	
+	$restriction = 
+		// OR
+		Array(RES_OR,
+				 Array(
+					   Array(RES_AND,	// Normal items: itemEnd must be after viewStart, itemStart must be before viewEnd
+							 Array(
+								   Array(RES_PROPERTY,
+										 Array(RELOP => RELOP_GT,
+											   ULPROPTAG => $properties["duedate"],
+											   VALUE => $viewstart
+											   )
+										 ),
+								   Array(RES_PROPERTY,
+										 Array(RELOP => RELOP_LT,
+											   ULPROPTAG => $properties["startdate"],
+											   VALUE => $viewend
+											   )
+										 )
+								   )
+							 ),
+					   // OR
+					   Array(RES_PROPERTY,
+							 Array(RELOP => RELOP_EQ,
+								   ULPROPTAG => $properties["recurring"],
+								   VALUE => true
+								   )
+							 )
+					   ) // EXISTS OR
+				 );		// global OR
+
+	// Get requested properties, plus whatever we need		    
+	$proplist = array(PR_ENTRYID, $properties["recurring"], $properties["recurring_data"], $properties["timezone_data"]);
+	$proplist = array_merge($proplist, $propsrequested);
+	$propslist = array_unique($proplist);
+	
+	$rows = mapi_table_queryallrows($table, $proplist, $restriction);
+	
+	// $rows now contains all the items that MAY be in the window; a recurring item needs expansion before including in the output.
+	
+	foreach($rows as $row) {
+		$items = array();
+		
+		if(isset($row[$properties["recurring"]]) && $row[$properties["recurring"]]) {
+			// Recurring item
+			$rec = new Recurrence($store, $row);
+
+			// GetItems guarantees that the item overlaps the interval <$viewstart, $viewend>                    
+			$occurrences = $rec->getItems($viewstart, $viewend);
+			foreach($occurrences as $occurrence) {
+				// The occurrence takes all properties from the main row, but overrides some properties (like start and end obviously)
+				$item = $occurrence + $row;
+				array_push($items, $item);
+			}
+			
+		} else {
+			// Normal item, it matched the search criteria and therefore overlaps the interval <$viewstart, $viewend>
+			array_push($items, $row);
+		}
+		
+		$result = array_merge($result,$items);
+	}
+	
+	// All items are guaranteed to overlap the interval <$viewstart, $viewend>. Note that we may be returning a few extra
+	// properties that the caller did not request (recurring, etc). This shouldn't be a problem though.
+	return $result;
+}
+?>
