@@ -424,6 +424,7 @@ define('olNonMeeting'                            ,0);
 define('olMeeting'                               ,1);
 define('olMeetingReceived'                       ,3);
 define('olMeetingCanceled'                       ,5);
+define('olMeetingReceivedAndCanceled'            ,7);
     
 /*    OlMeetingResponse */
 define('olMeetingTentative'                      ,2);
@@ -488,7 +489,7 @@ define('RESTRICTION'                             ,10);        // RES_COMMENT and
 define("ZARAFA_SERVICE_GUID"                     ,makeGuid("{3C253DCA-D227-443C-94FE-425FAB958C19}"));    // default store
 define("ZARAFA_STORE_PUBLIC_GUID"                ,makeGuid("{D47F4A09-D3BD-493C-B2FC-3C90BBCB48D4}"));    // public store
 define("ZARAFA_STORE_DELEGATE_GUID"              ,makeGuid("{7C7C1085-BC6D-4E53-9DAB-8A53F8DEF808}"));    // other store
-
+define('ZARAFA_STORE_ARCHIVER_GUID'              ,makeGuid("{BC8953AD-2E3F-4172-9404-896FF459870F}"));    // archive store
 
 /* Permissions */
 
