@@ -69,6 +69,15 @@
 	ob_start();
 	setlocale(LC_CTYPE, "en_US.UTF-8");
 
+	// Set timezone
+	if(function_exists("date_default_timezone_set")) {
+		if(defined('TIMEZONE') && TIMEZONE) {
+			date_default_timezone_set(TIMEZONE);
+		} else if(!ini_get('date.timezone')) {
+			date_default_timezone_set('Europe/London');
+		}
+	}
+
 	// Start the session
 	session_name(COOKIE_NAME);
 
