@@ -618,13 +618,16 @@ class Conversion {
 			}
 
 			if (isset($xmlitem["flavor"])){
-				if ($xmlitem["flavor"]==0){
-					$action["flavor"] = 0;
-				}else{
-				    if(defined($xmlitem["flavor"])) 
-    					$action["flavor"] = constant($xmlitem["flavor"]);
-                    else
-                        $action["flavor"] = $xmlitem["flavor"];
+				$action["flavor"] = 0;
+				$flavors = explode("|", $xmlitem["flavor"]);
+
+				foreach($flavors as $flavor){
+					$flavor = trim($flavor);
+					if (defined($flavor)) {
+						$action["flavor"] += constant($flavor);
+					} else {
+						$action["flavor"] += intval($flavor, 10);
+					}
 				}
 			}
 
@@ -641,7 +644,8 @@ class Conversion {
 			}
 
 			if (isset($xmlitem["proptag"])){
-				$action["proptag"][Conversion::propTagFromXML($xmlitem["proptag"])] = null;
+				/* FIXME ignoring actual value in $xmlitem */
+				$action["proptag"][Conversion::propTagFromXML($xmlitem["proptag"])] = array();
 			}
 
 			$binaryentries = array("storeentryid", "folderentryid", "replyentryid", "replyguid");
@@ -679,7 +683,7 @@ class Conversion {
 						break;
 					case "flavor":
 						if ($action["action"]==OP_FORWARD||$action["action"]==OP_REPLY){
-							$xml_action["flavor"] = Conversion::getFlavorName($val);
+							$xml_action["flavor"] = Conversion::getFlavorName($val, $action["action"]);
 						}
 						break;
 	
@@ -710,7 +714,11 @@ class Conversion {
 					case "proptag":
 						if(is_array($val) && count($val) > 0) {
 							// assume there will be only one proptag
-							$xml_action["proptag"] = Conversion::getPropertyName(key($val));
+							$tag = key($val);
+							
+							$xml_action["proptag"] = Conversion::mapProp2XML($tag, $val[$tag]);
+							$xml_action["proptag"]["attributes"]["proptag"] = Conversion::getPropertyName($tag);
+							
 						}
 						break;
 					case "code":
@@ -797,23 +805,35 @@ class Conversion {
 	*
 	* @access private
 	* @param string $flavor string representation of the flavor from XML
+	* @param Number $actionType Number representing action type (OP_REPLY or OP_FORWARD)
 	* @return int MAPI flavor ID
 	*/
-	function getFlavorName($flavor)
+	function getFlavorName($flavor, $actionType)
 	{
-		switch($flavor){
-			case STOCK_REPLY_TEMPLATE:
-				return "STOCK_REPLY_TEMPLATE";
-			case DO_NOT_SEND_TO_ORIGINATOR:
-				return "DO_NOT_SEND_TO_ORIGINATOR";
-			case FWD_PRESERVE_SENDER:
-				return "FWD_PRESERVE_SENDER";
-			case FWD_DO_NOT_MUNGE_MSG:
-				return "FWD_DO_NOT_MUNGE_MSG";
-			case FWD_AS_ATTACHMENT:
-				return "FWD_AS_ATTACHMENT";
+		$flavors = array();
+
+		if($actionType == OP_REPLY) {
+			if (($flavor & STOCK_REPLY_TEMPLATE) === STOCK_REPLY_TEMPLATE)
+				$flavors[] = "STOCK_REPLY_TEMPLATE";
+
+			if (($flavor & DO_NOT_SEND_TO_ORIGINATOR) === DO_NOT_SEND_TO_ORIGINATOR)
+				$flavors[] = "DO_NOT_SEND_TO_ORIGINATOR";
+		} else if ($actionType == OP_FORWARD) {
+			if (($flavor & FWD_PRESERVE_SENDER) === FWD_PRESERVE_SENDER)
+				$flavors[] = "FWD_PRESERVE_SENDER";
+
+			if (($flavor & FWD_DO_NOT_MUNGE_MSG) === FWD_DO_NOT_MUNGE_MSG)
+				$flavors[] = "FWD_DO_NOT_MUNGE_MSG";
+
+			if (($flavor & FWD_AS_ATTACHMENT) === FWD_AS_ATTACHMENT)
+				$flavors[] = "FWD_AS_ATTACHMENT";
+		}
+
+		if(!empty($flavors)) {
+			return implode(" | ", $flavors);
+		} else {
+			return $flavor;
 		}
-		return $flavor;
 	}
 
 	/**
@@ -1007,6 +1027,11 @@ class Conversion {
 						 */
 						$propTagForValue = Conversion::convertToSingleValuedProperty($propTag);
 						$propValue = $prop[VALUE][$propTagForValue];
+						
+						// Empty MV property (cValues = 0)
+						if(!isset($propValue)) {
+							$propValue = array();
+						}
 					} else {
 						$propTagForValue = $propTag;
 						$propValue = $prop[VALUE][$propTag];
