@@ -192,16 +192,17 @@ class CreateZipFile {
 	 * Function to force the download of the archive as soon as it is created
 	 *
 	 * @param archiveName string - name of the created archive file
+	 * @param downloadName string - offered download name
 	 * @access public
 	 * @return ZipFile via Header
 	 */
-	public function forceDownload($archiveName) {
+	public function forceDownload($archiveName, $downloadName) {
 		header("Pragma: public");
 		header("Expires: 0");
 		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
 		header("Cache-Control: private",false);
 		header("Content-Type: application/zip");
-		header("Content-Disposition: attachment; filename=".basename($archiveName).";" );
+		header("Content-Disposition: attachment; filename=".browserDependingHTTPHeaderEncode($downloadName).";" );
 		header("Content-Transfer-Encoding: binary");
 		header("Content-Length: ".filesize($archiveName));
 		readfile("$archiveName");
