@@ -72,7 +72,7 @@
 		 * @param string $entryid MAPI message entryid, is used for the inline attachments and new mail
 		 * @return string safe html		
 		 */		 		
-		function safeHTML($html, $storeid = false, $entryid = false)
+		function safeHTML($html, $storeid = false, $entryid = false, $attachNum = false)
 		{
 			// Save all "<" symbols
 			$html = preg_replace("/<(?=[^a-zA-Z\/\!\?\%])/", "&lt;", $html); 
@@ -95,6 +95,7 @@
 			$GLOBALS["preg_replace"] = array();
 			$GLOBALS["preg_replace"]["storeid"] = $storeid;
 			$GLOBALS["preg_replace"]["entryid"] = $entryid;
+			$GLOBALS["preg_replace"]["attachNum"] = $attachNum;
 
 			// inline images can be specified without cid: tag also so replace that also, but exclude external link to images
 			$html = preg_replace_callback('/<img[^>]*src\s*=\s*[\"\']([^\"\']*)[\"\'].*?>/msi', "inline_img_attachments", $html);
