@@ -151,8 +151,10 @@
 				if (strtoupper(substr(PHP_OS, 0, 3)) === "WIN"){
 					$this->loadLanguages(); // we need the languagetable for windows...
 					setlocale(LC_MESSAGES,$this->languagetable[$lang]);
+					setlocale(LC_TIME,$this->languagetable[$lang]);
 				}else{
 					setlocale(LC_MESSAGES,$lang);
+					setlocale(LC_TIME,$lang);
 				}
 
 				bindtextdomain('zarafa' , LANGUAGE_DIR);
