@@ -161,6 +161,8 @@
 	  		$properties["icon_index"] = PR_ICON_INDEX;
 	  		$properties["subject"] = PR_SUBJECT;
 	  		$properties["display_to"] = PR_DISPLAY_TO;
+	  		$properties["display_cc"] = PR_DISPLAY_CC;
+	  		$properties["display_bcc"] = PR_DISPLAY_BCC;
 	  		$properties["importance"] = PR_IMPORTANCE;
 	  		$properties["sensitivity"] = PR_SENSITIVITY;
 			$properties["sent_representing_entryid"] = PR_SENT_REPRESENTING_ENTRYID;
@@ -204,8 +206,7 @@
 			$properties["body"] = PR_BODY;
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
-			// 
-			
+
 			// Propose new time properties
 			$properties["proposed_start_whole"] = "PT_SYSTIME:PSETID_Appointment:0x8250";
 			$properties["proposed_end_whole"] = "PT_SYSTIME:PSETID_Appointment:0x8251";
@@ -297,6 +298,7 @@
 			// Detailed contacts properties
 			// Properties for phone numbers
 			$properties["assistant_telephone_number"] = PR_ASSISTANT_TELEPHONE_NUMBER;
+			$properties["business_telephone_number"] = PR_BUSINESS_TELEPHONE_NUMBER;
 			$properties["business2_telephone_number"] = PR_BUSINESS2_TELEPHONE_NUMBER;
 			$properties["callback_telephone_number"] = PR_CALLBACK_TELEPHONE_NUMBER;
 			$properties["car_telephone_number"] = PR_CAR_TELEPHONE_NUMBER;
