@@ -92,9 +92,9 @@ class TableColumns {
 		$this->addColumn($tableColumns, "contacts", false, 10, _("Contacts"), _("Sort on Contact"));
 
 		// Columns for Attendees
-		$this->addColumn($tableColumns, "required", false, 11, _("Required Attendee"), _("Sort on Attendee"));
-		$this->addColumn($tableColumns, "optional", false, 12, _("Optional Attendee"), _("Sort on Attendee"));
-		$this->addColumn($tableColumns, "resource", false, 13, _("Resource"), _("Sort on Attendee"));
+		$this->addColumn($tableColumns, "display_to", false, 11, _("Required Attendee"), _("Sort on Required Attendee"));
+		$this->addColumn($tableColumns, "display_cc", false, 12, _("Optional Attendee"), _("Sort on Optional Attendee"));
+		$this->addColumn($tableColumns, "display_bcc", false, 13, _("Resource"), _("Sort on Resource"));
 
 		$this->addColumn($tableColumns, "busystatus", false, 5, _("Busy Status"), _("Sort on Busy Status"));
 
