@@ -654,6 +654,20 @@ function sq_fixatts($tagname,
             }
         }
 
+        if ($attname == 'href' || $attname == 'src' || $attname == 'background') {
+            # If you type \\server\share into Outlook, then it will put
+            # file:/// in front of it, making it file:///\\server\share.
+            # Transform this into file://///server/share.  The extra
+            # slashes are required to make it work for Firefox as well.
+            if (preg_match("/^['\"]file:\\/\\/\\/?\\\\\\\\([^\\\\]+)\\\\([^\\\\]+)(\\\\.*)?['\"]$/", $attvalue, $aMatch)) {
+                $attvalue = "\"file://///" . $aMatch[1] . "/" .
+                    $aMatch[2] . str_replace(Array("\\"), Array("/"),
+                                             $aMatch[3]) . "\"";
+            }
+        }
+
+
+
         /**
          * Workaround for IE quirks
          */
@@ -1006,11 +1020,21 @@ function sq_sanitize($body,
          * Take care of <style>
          */
         if ($tagname == "style" && $tagtype == 1){
-            list($free_content, $curpos) =
+			/**
+			 * this checks for <p>CONTENT<style></style></p>
+			 * so here when the current tag is <style> and there is some text/content before the start of that tag 
+			 * then we would like to copy that to $trusted string.
+			 */
+			if($free_content != FALSE){
+					$trusted .= $free_content;
+				}
+
+			list($style_content, $curpos) =
                 sq_fixstyle($body, $gt+1, $message, $id, $mailbox);
-            if ($free_content != FALSE){
+			
+            if ($style_content != FALSE){
                 $trusted .= sq_tagprint($tagname, $attary, $tagtype);
-                $trusted .= $free_content;
+                $trusted .= $style_content;
                 $trusted .= sq_tagprint($tagname, false, 2);
             }
             continue;
