@@ -109,24 +109,6 @@
 		{
 			$result = false;
 
-			// open localfreebusy folder for delegate permissions
-			$rootFolder = mapi_msgstore_openentry($store, null);
-			$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
-			/**
-			 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
-			 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
-			 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
-			 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
-			 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
-			 */
-			// get localfreebusy folder
-			$this->localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
-			if(mapi_last_hresult() !== NOERROR) {
-				$this->localFreeBusyFolder = false;
-			}
-
-			$this->storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
-
 			if($store && $entryid) {
 				$type = false;
 				
@@ -156,11 +138,9 @@
 					array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
 				}else{
-					//for list view in calendar as startdate and enddate in passed as false
-					//this will set sorting and paging for items in listview.
+					// for list view in calendar as startdate and enddate in passed as false
+					// this will set sorting and paging for items in listview.
 					
-					//to generate recipient xml for appointments  
-					$this->generateRecipient = true;
 					$result = parent::messageList($store, $entryid, $action);
 				}
 			}
@@ -236,12 +216,12 @@
 							$item["basedate"]["attributes"]["unixtime"] = $recuritem["basedate"];
 							$item["basedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $recuritem["basedate"]);
 						}
-						$item = $this->disablePrivateItem($item);
+						$item = $this->disablePrivateItem($item, true);
 						array_push($items, $item);
 					}
 				} else {
 					$item = Conversion::mapMAPI2XML($this->properties, $calendaritem);
-					$item = $this->disablePrivateItem($item);
+					$item = $this->disablePrivateItem($item, true);
 					array_push($items,$item);
 				}
 
@@ -251,47 +231,6 @@
 			return $items;
 		}
 
-		/**
-		 * Function to remove some properties when the item is private
-		 * and it will also check for delegate permissions
-		 * @param object $item item properties
-		 * @return object $item item with modified properties
-		 */
-		function disablePrivateItem($item)
-		{
-			if(isset($item["private"]) && $item["private"] == true) {
-				// check for delegate permissions
-				if($this->storeProviderGuid[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
-					$hideItemData = true;
-
-					// find delegate properties
-					if($this->localFreeBusyFolder !== false) {
-						$localFreeBusyFolderProps = mapi_getprops($this->localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
-						if(mapi_last_hresult() === NOERROR) {
-							if(isset($localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]) && isset($localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE])) {
-								// if more then one delegates info is stored then find index of 
-								// current user
-								$userEntryId = $GLOBALS["mapisession"]->getUserEntryID();
-								$userIndex = array_search($userEntryId, $localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]);
-
-								if($userIndex !== false && $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$userIndex] === 1) {
-									$hideItemData = false;
-								}
-							}
-						}
-					}
-
-					if($hideItemData) {
-						$item["subject"] = _("Private Appointment");
-						$item["location"] = "";
-						$item["reminder"] = 0;
-						$item["disabled_item"] = 1;
-					}
-				}
-			}
-			return $item;
-		}
-
 		/**
 		 * Function which saves an item. This function saves a normal appointment, a
 		 * recurring items and its exceptions and meetingrequests.
