@@ -92,6 +92,7 @@
 					switch($action["attributes"]["type"])
 					{
 						case "list":
+							$this->getDelegateFolderInfo($store);
 							if ($this->searchActive) {
 								// if search is active then send results from search folder
 								$result = $this->search($store, $entryid, $action);
@@ -309,7 +310,13 @@
 					$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc" : "desc";
 					$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
 
-					$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $sort, $this->start, false, $restriction));
+					$items = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $sort, $this->start, false, $restriction));
+					
+					for($i=0; $i<count($items["item"]); $i++){
+						// Disable private items
+						$items["item"][$i] = $this->disablePrivateItem($items["item"][$i]);
+					}
+					$data = array_merge($data, $items);
 
 					array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
