@@ -249,8 +249,16 @@
 				 * equipment --> DT_EQUIPMENT
 				 * contact --> DT_REMOTE_MAILUSER
 				 */
-				if(DTE_IS_ACL_CAPABLE($user_data[PR_DISPLAY_TYPE_EX]) === false && (DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX]) == DT_ROOM || DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX]) == DT_EQUIPMENT || DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX]) == DT_MAILUSER)) {
-					$result["recipienttype"] = MAPI_BCC;		// resource
+				if(DTE_IS_ACL_CAPABLE($user_data[PR_DISPLAY_TYPE_EX]) === false){
+					switch (DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX])){
+						case DT_EQUIPMENT:
+						case DT_ROOM:
+							$result["recipienttype"] = MAPI_BCC; // resource
+							break;
+						case DT_MAILUSER:
+							$result["recipienttype"] = MAPI_TO; // required attendee
+							break;
+					}
 				} else {
 					if($organizer) {
 						$result["recipienttype"] = MAPI_ORIG;			// organizer
