@@ -145,7 +145,7 @@
 							 * After Accepting/Declining the message is moved and changed.
 							 */
 							$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
-							$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+							$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession(), ENABLE_DIRECT_BOOKING);
 
 							// Update extra body information
 							if(isset($action['meetingTimeInfo']) && strlen($action['meetingTimeInfo'])) {
@@ -193,8 +193,25 @@
 								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps); // send TABLE_SAVE event because an occurrence is deleted
 							break;
 						case "cancelInvitation":
-							$GLOBALS["operations"]->cancelInvitation($store, $entryid, $action);
-							
+							$accessToFolder = false;
+							// Find the parententryid using the store and the entryid when it has not been sent in the request
+							if($store && $entryid && !$parententryid){
+								$folder = mapi_msgstore_openentry($store, $entryid);
+								$folderProps = mapi_getprops($folder, Array(PR_PARENT_ENTRYID));
+								$parententryid = $folderProps[PR_PARENT_ENTRYID];
+							}
+
+							if($store && $parententryid)
+								$accessToFolder = $GLOBALS["operations"]->checkFolderAccess($store, $parententryid);
+
+							if($accessToFolder) {
+								// If folder is accessible then cancel inviation the message.
+								$GLOBALS["operations"]->cancelInvitation($store, $entryid, $action);
+							} else {
+								// If folder is not accessible then show error message.
+								$errorMessage = _("You have insufficient privileges to delete items in this folder") . ".";
+								$this->sendFeedback(false, $errorMessage);
+							}
 							break;
 						case "removeFromCalendar":
 							$GLOBALS["operations"]->removeFromCalendar($store, $entryid);
@@ -426,6 +443,12 @@
 								}
 								
 								switch($parts["type"]) {
+		                            case 0:
+										$item["missing"] = "0";
+										$item["distlisttype"] = "ONEOFF";
+										$item["icon_index"] = 512;
+										$item["message_class"] = "IPM.DistListItem.OneOffContact";
+										break;
 									case DL_USER:
 										$item["distlisttype"] = "DL_USER";
 										$item["icon_index"] = 512;
@@ -470,7 +493,7 @@
 
 				// Check for meeting request, do processing if necessary
 				if(isset($data["item"]["message_class"]) && strpos($data["item"]["message_class"], "IPM.Schedule.Meeting") !== false) {
-					$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+					$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession(), ENABLE_DIRECT_BOOKING);
 					if($req->isMeetingRequestResponse()) {
 						if($req->isLocalOrganiser()) {
 							// We received a meeting request response, and we're the organiser
@@ -644,6 +667,18 @@
 				
 				if($result) {
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_DELETE, $props);
+
+					// Notify the client of the successful delete action
+					$data = array();
+					$data["attributes"] = array("type" => "deleted");
+					$data['item'] = Array(
+						'entryid' => bin2hex($entryid),
+						'parent_entryid' => bin2hex($parententryid),
+						'store_entryid' => bin2hex($storeprops[PR_ENTRYID])
+					);
+					array_push($this->responseData["action"], $data);
+					$GLOBALS["bus"]->addData($this->responseData);
+
 				}
 			}
 		
@@ -873,4 +908,4 @@
 			$GLOBALS["bus"]->addData($this->responseData);
 		}
 	}
-?>
\ No newline at end of file
+?>
