@@ -123,12 +123,6 @@
 		 */
 		var $useSearchFolder;
 
-		/**
-		 * @var bool checks whether to look for recipients in appointmentlistmodule
-		 *  and add them in items or just get items without recipients tag. 
-		 */
-		var $generateRecipient;
-
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -144,7 +138,6 @@
 			$this->searchFolderEntryId = false;
 			$this->searchCriteriaCheck = false;
 			$this->useSearchFolder = false;
-			$this->generateRecipient = false;
 
 			$this->sort = array();
 			
@@ -169,6 +162,7 @@
 					switch($action["attributes"]["type"])
 					{
 						case "list":
+							$this->getDelegateFolderInfo($store);
 							$result = $this->messageList($store, $entryid, $action);
 							break;
 						case "save":
@@ -201,14 +195,32 @@
 							$result = $this->copy($store, $parententryid, $entryid, $action);
 							break;
                         case "cancelInvitation":
-                            $GLOBALS["operations"]->cancelInvitation($store, $entryid, $action);
+							$accessToFolder = false;
+							// Find the parententryid using the store and the entryid when it has not been sent in the request
+							if($store && $entryid && !$parententryid){
+								$folder = mapi_msgstore_openentry($store, $entryid);
+								$folderProps = mapi_getprops($folder, Array(PR_PARENT_ENTRYID));
+								$parententryid = $folderProps[PR_PARENT_ENTRYID];
+							}
+
+							if($store && $parententryid)
+								$accessToFolder = $GLOBALS["operations"]->checkFolderAccess($store, $parententryid);
+
+							if($accessToFolder) {
+								// If folder is accessible then cancel inviation the message.
+								$GLOBALS["operations"]->cancelInvitation($store, $entryid, $action);
+							} else {
+								// If folder is not accessible then show error message.
+								$errorMessage = _("You have insufficient privileges to delete items in this folder") . ".";
+								$this->sendFeedback(false, $errorMessage);
+							}
                             break;
 						case "declineMeeting":
 							if (isset($action["props"]) && isset($action["props"]["entryid"])) {
 								$message = $GLOBALS["operations"]->openMessage($store, hex2bin($action["props"]["entryid"]));
 								$basedate = (isset($action["props"]['basedate']) ? $action["props"]['basedate'] : false);
 
-								$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+								$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession(), ENABLE_DIRECT_BOOKING);
 
 								$body = isset($action["body"]) ? $action["body"] : false;
 								$req->doDecline(true, $store, $basedate, $body);
@@ -280,14 +292,12 @@
 				$data["sort"]["_content"] = array_search($firstSortColumn &~ MV_INSTANCE, $this->properties);
 
 				// Get the table and merge the arrays
-				$items = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction, $this->generateRecipient);
-
-				for($i=0; $i<count($items["item"]); $i++)
-				{
+				$items = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction);
+				
+				for($i=0; $i<count($items["item"]); $i++){
 					// Disable private items
 					$items["item"][$i] = $this->disablePrivateItem($items["item"][$i]);
 				}
-
 				$data = array_merge($data, $items);
 
 				array_push($this->responseData["action"], $data);
@@ -418,7 +428,7 @@
 
 			// Get the table and merge the arrays
 			$rowcount = $GLOBALS["settings"]->get("global/rowcount", 50);
-			$table = $GLOBALS["operations"]->getTable($store, hex2bin($this->searchFolderEntryId), $this->properties, $this->sort, $this->start, $rowcount, false, $this->generateRecipient);
+			$table = $GLOBALS["operations"]->getTable($store, hex2bin($this->searchFolderEntryId), $this->properties, $this->sort, $this->start, $rowcount, false);
 			$data = array_merge($data, $table);
 
 			// remember which entryid's are send to the client
@@ -1100,11 +1110,70 @@
 		 * Basically, function will to remove some properties when the item is private
 		 * and it will also check for delegate permissions.
 		 * @param object $item item properties
+		 * @param flag $displayItem checks wheather we should display the private items
 		 * @return object $item item with modified properties
 		 */
-		function disablePrivateItem($item) 
+		function disablePrivateItem($item, $displayItem = false) 
 		{
-			return $item;
+			$hideItemData = false;
+
+			if((isset($item["private"]) && $item["private"] == true) || (isset($item["sensitivity"]) && $item["sensitivity"] == SENSITIVITY_PRIVATE)) {
+				// check for delegate permissions
+				if($this->storeProviderGuid[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
+					$hideItemData = true;
+
+					// find delegate properties
+					if($this->localFreeBusyFolder !== false) {
+						$localFreeBusyFolderProps = mapi_getprops($this->localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
+						if(mapi_last_hresult() === NOERROR) {
+							if(isset($localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]) && isset($localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE])) {
+								// if more then one delegates info is stored then find index of 
+								// current user
+								$userEntryId = $GLOBALS["mapisession"]->getUserEntryID();
+								$userIndex = array_search($userEntryId, $localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]);
+
+								if($userIndex !== false && $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$userIndex] === 1) {
+									$hideItemData = false;
+								}
+							}
+						}
+					}
+				}
+			}
+			if($hideItemData && $displayItem) {
+				$item["subject"] = _("Private Appointment");
+				$item["location"] = "";
+				$item["reminder"] = 0;
+				$item["disabled_item"] = 1;
+				return $item;
+			} else if(!$hideItemData){
+				return $item;
+			}
+		}
+		
+		/**
+		 * Function which gets the delegation details from localfreebusy folder 
+		 * @param object $store MAPI Message Store Object
+		 */
+		function getDelegateFolderInfo($store)
+		{	
+			$this->storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
+
+			// open localfreebusy folder for delegate permissions
+			$rootFolder = mapi_msgstore_openentry($store, null);
+			$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
+			/**
+			 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
+			 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
+			 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
+			 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
+			 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
+			 */
+			// get localfreebusy folder
+			$this->localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
+			if(mapi_last_hresult() !== NOERROR) {
+				$this->localFreeBusyFolder = false;
+			}
 		}
 	}
 ?>
