@@ -122,6 +122,7 @@
 					switch($action["attributes"]["type"])
 					{
 						case "list":
+							$this->getDelegateFolderInfo($store);
 							if ($this->searchActive) {
 								$result = $this->search($store, $entryid, $action);
 							} else {
@@ -185,7 +186,7 @@
 								 * After Accepting/Declining the message is moved and changed.
 								 */
 								$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
-								$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+								$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession(), ENABLE_DIRECT_BOOKING);
 
 								$basedate = (isset($action['basedate']) ? $action['basedate'] : false);
 								// sendResponse flag if it is set then send the mail response to the organzer.
@@ -416,7 +417,13 @@
 			$data["isinbox"]["_content"] = $folderprops[PR_ENTRYID] == $inboxentryid;
 				
 			// Get the table and merge the arrays
-			$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction));
+			$items = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction));
+
+			for($i=0; $i<count($items["item"]); $i++){
+				// Disable private items
+				$items["item"][$i] = $this->disablePrivateItem($items["item"][$i]);
+			}
+			$data = array_merge($data, $items);
 				
 			array_push($this->responseData["action"], $data);
 			$GLOBALS["bus"]->addData($this->responseData);
