@@ -162,23 +162,6 @@
 			$folder = mapi_msgstore_openentry($store, $entryid);
 			$table = mapi_folder_getcontentstable($folder);
 			$calendaritems = mapi_table_queryallrows($table, $this->properties, $restriction);
-			$storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
-			
-			// open localfreebusy folder for delegate permissions
-			$rootFolder = mapi_msgstore_openentry($store, null);
-			$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
-			/**
-			 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
-			 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
-			 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
-			 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
-			 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
-			 */
-			// get localfreebusy folder
-			$localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
-			if(mapi_last_hresult() !== NOERROR) {
-				$localFreeBusyFolder = false;
-			}
 
 			foreach($calendaritems as $calendaritem)
 			{
@@ -200,12 +183,12 @@
 							$item["basedate"]["attributes"]["unixtime"] = $recuritem["basedate"];
 							$item["basedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $recuritem["basedate"]);
 						}
-						$item = $this->disablePrivateItem($localFreeBusyFolder, $storeProviderGuid[PR_MDB_PROVIDER], $item);
+						$item = $this->disablePrivateItem($item, true);
 						array_push($items, $item);
 					}
 				} else {
 					$item = Conversion::mapMAPI2XML($this->properties, $calendaritem);
-					$item = $this->disablePrivateItem($localFreeBusyFolder, $storeProviderGuid[PR_MDB_PROVIDER], $item);
+					$item = $this->disablePrivateItem($item, true);
 					array_push($items,$item);
 				}
 
@@ -215,54 +198,6 @@
 			return $items;
 		}
 
-		/**
-		 * Function to remove some properties when the item is private
-		 * and it will also check for delegate permissions
-		 * @param object $localFreeBusyFolder localfreebusy folder
-		 * @param object $storeproviderguid type of store
-		 * @param object $item item properties
-		 * @return object $item item with modified properties
-		 */
-		function disablePrivateItem($localFreeBusyFolder, $storeProviderGuid, $item)
-		{
-			if(isset($item["private"]) && $item["private"] == true) {
-				// check for delegate permissions
-				if($storeProviderGuid == ZARAFA_STORE_DELEGATE_GUID) {
-					$hideItemData = false;
-
-					if($localFreeBusyFolder === false) {
-						$hideItemData = true;
-					}
-
-					// find delegate properties
-					if($localFreeBusyFolder !== false) {
-						$localFreeBusyFolderProps = mapi_getprops($localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
-						if(mapi_last_hresult() !== NOERROR) {
-							// no delegate properties exists
-							$hideItemData = true;
-						} else {
-							// if more then one delegates info is stored then find index of 
-							// current user
-							$userEntryId = $GLOBALS["mapisession"]->getUserEntryID();
-							$userIndex = array_search($userEntryId, $localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]);
-
-							if($userIndex === false || $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$userIndex] === 0) {
-								$hideItemData = true;
-							}
-						}
-					}
-
-					if($hideItemData) {
-						$item["subject"] = _("Private Appointment");
-						$item["location"] = "";
-						$item["reminder"] = 0;
-						$item["disabled_item"] = 1;
-					}
-				}
-			}
-			return $item;
-		}
-
 		/**
 		 * Function will sort items for the month view
 		 * small startdate->attributes->unixtime on top	 
