@@ -289,38 +289,36 @@
 
 			foreach($rows as $row) {
 				if(isset($row[$this->properties["appointment_recurring"]]) && $row[$this->properties["appointment_recurring"]]) {
-					// Do extra checks for recurring items:
-					// - Check if there really is a reminder between the flagdueby and now. If not, there's no reminder yet. If there
-					// are more than one reminder, use the last.
 					$recur = new Recurrence($store, $row);
-					
+
 					/**
-					 * Fetch occurences of reminder which taken place between remindertime and currenttime.
-					 * Here reminder_minutes is added in current time to also get
-					 * those occurrences for which reminder is activated.
-					 * remindertime property returns a Date indicating the date and time
-					 * at which the reminder should occur for the specified item.
-					 * For recurring event it will save the time of first reminder of recurrence.
+					 * FlagDueBy handles whether we should be showing the item; if now() is after FlagDueBy, then we should show a reminder
+					 * for this recurrence. However, the item we will show is either the last passed occurrence (overdue), or the next occurrence, depending
+					 * on whether we have reached the next occurrence yet (the remindertime of the next item is ignored).
+					 *
+					 * The way we handle this is to get all occurrences between the 'flagdueby' moment and the current time. This will
+					 * yield N items (may be a lot of it was not dismissed for a long time). We can then take the last item in this list, and this is the item
+					 * we will show to the user. The idea here is:
+					 *
+					 * The item we want to show is the last item in that list (new occurrences that have started uptil now should override old ones)
 					 */
-					$occurrences = $recur->getItems($row[$this->properties["remindertime"]], time() + ($row[$this->properties["reminder_minutes"]] * 60), 0, true);
+					$occurrences = $recur->getItems($row[$this->properties["flagdueby"]], time(), 0, true);
 
 					if(count($occurrences) == 0)
 						continue;
-						
-					// Update the reminder time to show as the last occurrence since 'remindertime' until now
-					$lastocc = $occurrences[count($occurrences)-1];
 
+					$occ = $occurrences[count($occurrences)-1];
 
 					// Bydefault, on occurrence reminder is true but if reminder value is set to false then we don't send popup reminder for this occurrence
-					if (!(isset($lastocc[$this->properties['reminder']]) && $lastocc[$this->properties['reminder']] == 0)) {
-						$row[$this->properties["remindertime"]] = $lastocc[$this->properties["appointment_startdate"]];
-						$row[$this->properties["appointment_startdate"]] = $lastocc[$this->properties["appointment_startdate"]];
-						$row[$this->properties["appointment_enddate"]] = $lastocc[$this->properties["appointment_startdate"]];
+					if (!(isset($occ[$this->properties['reminder']]) && $occ[$this->properties['reminder']] == 0)) {
+						$row[$this->properties["remindertime"]] = $occ[$this->properties["appointment_startdate"]];
+						$row[$this->properties["appointment_startdate"]] = $occ[$this->properties["appointment_startdate"]];
+						$row[$this->properties["appointment_enddate"]] = $occ[$this->properties["appointment_startdate"]];
 					}
 				}
 
 				// Add the non-bogus rows
-				 array_push($data["item"], Conversion::mapMAPI2XML($this->properties, $row));
+				array_push($data["item"], Conversion::mapMAPI2XML($this->properties, $row));
 			}
 			
 			// Generate this handy MD5 so that the client can easily detect changes
