@@ -201,7 +201,7 @@
 	function inline_attachments($match)
 	{
 		if(array_key_exists("2", $match)) {
-			return "='" . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $match[2] . "&amp;openType=inline'";
+			return "='" . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachNum[]=" . join(",", $GLOBALS["preg_replace"]["attachNum"]) ."&amp;attachCid=" . $match[2] . "&amp;openType=inline'";
 		} else {
 			return "=''";
 		}
@@ -226,7 +226,7 @@
 
 			$cid = str_replace("cid:", "", $match[1]);
 
-			return str_replace($match[1], BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $cid . "&amp;openType=inline\"", $match[0]);
+			return str_replace($match[1], BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachNum[]=" . join(",", $GLOBALS["preg_replace"]["attachNum"]) ."&amp;attachCid=" . $cid . "&amp;openType=inline\"", $match[0]);
 		} else {
 			return $match[0];
 		}
@@ -533,4 +533,16 @@
 		}
 	}
 
+	/**
+	 * Shortcut function that uses getPropIdsFromStrings() to convert a string to the proper ID of 
+	 * the named property. When the Id is retrieved it is converted to hex. 0xFFFFFFFF00000000 is 
+	 * substracted from the result.
+	 * @param String $id String with the ID of the property
+	 * @return String Hex ID of the named property preceeded by "0x"
+	 */
+	function convertStringToHexNamedPropId($id){
+		$propID = getPropIdsFromStrings($GLOBALS["mapisession"]->getDefaultMessageStore(), Array('prop'=>$id));
+		return '0x' . dechex( $propID['prop']&0xffffffff );
+	}
+
 ?>
